@@ -6,7 +6,6 @@ PREFIX=/Users/darco/Projects/Voria/synfig-build
 export PKG_CONFIG_PATH=$PREFIX/lib/pkgconfig:/usr/lib/pkgconfig:/usr/X11R6/lib/pkgconfig
 export MACOSX_DEPLOYMENT_TARGET=10.4
 OPTIONS="--prefix=$PREFIX"
-#OPTIONS="$OPTIONS --enable-timelimit=120"
 OPTIONS="$OPTIONS --enable-optimization=2"
 #OPTIONS="$OPTIONS --enable-optimization=3 --enable-g5opt"
 #OPTIONS="$OPTIONS --disable-optimization"
@@ -28,7 +27,7 @@ CPP="gcc -E"
 CXXCPP="g++ -E"
 
 
-[ -e configure ] || ./bootstrap || exit 1
+[ -e configure ] || autoreconf --force --install || exit 1
 
 [ -d $BUILDDIR ] && rm -fr $BUILDDIR
 
