@@ -128,18 +128,20 @@ About::About()
 #endif
 
 	std::vector<Glib::ustring> authors;
-	authors.push_back("Original developers:");
+	authors.push_back(_("Original developers:"));
 	authors.push_back("");
 	authors.push_back("Robert B. Quattlebaum Jr (darco)");
 	authors.push_back("Adrian Bentley");
 	authors.push_back("");
-	authors.push_back("Contributors:");
+	authors.push_back(_("Contributors:"));
 	authors.push_back("");
 	authors.push_back("Adrian Winchell (SnapSilverlight)");
 	authors.push_back("Andreas Jochens");
 	authors.push_back("Carlos López González (genete)");
+	authors.push_back("Carlos A. Sosa Navarro");
 	authors.push_back("Chris Moore (dooglus)");
 	authors.push_back("Chris Norman (pixelgeek)");
+	authors.push_back("Cyril Brulebois (KiBi)");
 	authors.push_back("Daniel Fort");
 	authors.push_back("Daniel Hornung (rubikcube)");
 	authors.push_back("David Roden (Bombe)");
@@ -148,22 +150,28 @@ About::About()
 	authors.push_back("Gerald Young (Yoyobuae)");
 	authors.push_back("Gerco Ballintijn");
 	authors.push_back("IL'dar AKHmetgaleev (AkhIL)");
+	authors.push_back("Konstantin Dmitriev (zelgadis)");
 	authors.push_back("Luka Pravica");
 	authors.push_back("Martin Michlmayr (tbm)");
 	authors.push_back("Miguel Gea Milvaques (xerakko)");
 	authors.push_back("Paul Wise (pabs)");
 	authors.push_back("Ralf Corsepius");
+	authors.push_back("Ray Frederikson");
+	authors.push_back("Timo Paulssen (timonator)");
 	authors.push_back("Yue Shi Lai");
 	set_authors(authors);
 
 	std::vector<Glib::ustring> artists;
-	artists.push_back("Robert B. Quattlebaum Jr. (darco)");
 	artists.push_back("Aurore D (rore)");
 	artists.push_back("Carlos López González (genete)");
 	artists.push_back("Chris Norman (pixelgeek)");
 	artists.push_back("Daniel Hornung (rubikcube)");
+	artists.push_back("David Rylander (rylleman)");
 	artists.push_back("Franco Iacomella (Yaco)");
-	
+	artists.push_back("Gerald Young (Yoyobuae)");
+	artists.push_back("Henrique Lopes Barone");
+	artists.push_back("Robert B. Quattlebaum Jr. (darco)");
+
 	set_artists(artists);
 
 	// TRANSLATORS: change this to your name, separate multiple names with \n
@@ -192,13 +200,13 @@ About::About()
 #ifdef SHOW_EXTRA_INFO
 
 	string extra_info = get_comments() + "\n";
-	
+
 	#ifdef DEVEL_VERSION
 		extra_info += strprintf(_("\nDevelopment version:\n%s\n"),DEVEL_VERSION);
 	#endif
-	
+
 	extra_info += "\n";
-	
+
 	extra_info += strprintf(_("Built on %s" /* at %s */ "\n"), __DATE__ /* , __TIME__ */ );
 
 	extra_info += "\n";
