@@ -2,7 +2,7 @@
 /*!	\file app.cpp
 **	\brief writeme
 **
-**	$Id: app.cpp 2098 2008-10-14 21:00:21Z genete $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -275,10 +275,13 @@ bool studio::App::use_colorspace_gamma=true;
 bool studio::App::single_threaded=false;
 #endif
 bool studio::App::restrict_radius_ducks=false;
+bool studio::App::resize_imported_images=false;
 String studio::App::custom_filename_prefix(DEFAULT_FILENAME_PREFIX);
 int studio::App::preferred_x_size=480;
 int studio::App::preferred_y_size=270;
 String studio::App::predefined_size(DEFAULT_PREDEFINED_SIZE);
+String studio::App::predefined_fps(DEFAULT_PREDEFINED_FPS);
+float studio::App::preferred_fps=24.0;
 #ifdef USE_OPEN_FOR_URLS
 String studio::App::browser_command("open"); // MacOS only
 #else
@@ -321,6 +324,34 @@ class GlobalUIInterface : public synfigapp::UIInterface
 {
 public:
 
+	virtual Response confirmation(const std::string &title,
+			const std::string &primaryText,
+			const std::string &secondaryText,
+			const std::string &confirmPhrase,
+			const std::string &cancelPhrase,
+			Response defaultResponse)
+	{
+		Gtk::MessageDialog dialog(
+			primaryText,		// Message
+			false,			// Markup
+			Gtk::MESSAGE_WARNING,	// Type
+			Gtk::BUTTONS_NONE,	// Buttons
+			true			// Modal
+		);
+
+		if (! title.empty())
+			dialog.set_title(title);
+		if (! secondaryText.empty())
+			dialog.set_secondary_text(secondaryText);
+
+		dialog.add_button(cancelPhrase, RESPONSE_CANCEL);
+		dialog.add_button(confirmPhrase, RESPONSE_OK);
+		dialog.set_default_response(defaultResponse);
+
+		dialog.show_all();
+		return (Response) dialog.run();
+	}
+
 	virtual Response yes_no(const std::string &title, const std::string &message,Response dflt=RESPONSE_YES)
 	{
 		Gtk::Dialog dialog(
@@ -511,6 +542,11 @@ public:
 			value=strprintf("%i",(int)App::restrict_radius_ducks);
 			return true;
 		}
+		if(key=="resize_imported_images")
+		{
+			value=strprintf("%i",(int)App::resize_imported_images);
+			return true;
+		}
 		if(key=="browser_command")
 		{
 			value=App::browser_command;
@@ -536,7 +572,17 @@ public:
 			value=strprintf("%s",App::predefined_size.c_str());
 			return true;
 		}
-		
+		if(key=="preferred_fps")
+		{
+			value=strprintf("%f",App::preferred_fps);
+			return true;
+		}
+		if(key=="predefined_fps")
+		{
+			value=strprintf("%s",App::predefined_fps.c_str());
+			return true;
+		}
+
 		return synfigapp::Settings::get_value(key,value);
 	}
 
@@ -600,6 +646,12 @@ public:
 			App::restrict_radius_ducks=i;
 			return true;
 		}
+		if(key=="resize_imported_images")
+		{
+			int i(atoi(value.c_str()));
+			App::resize_imported_images=i;
+			return true;
+		}
 		if(key=="browser_command")
 		{
 			App::browser_command=value;
@@ -627,6 +679,18 @@ public:
 			App::predefined_size=value;
 			return true;
 		}
+		if(key=="preferred_fps")
+		{
+			float i(atof(value.c_str()));
+			App::preferred_fps=i;
+			return true;
+		}
+		if(key=="predefined_fps")
+		{
+			App::predefined_fps=value;
+			return true;
+		}
+
 		return synfigapp::Settings::set_value(key,value);
 	}
 
@@ -643,11 +707,14 @@ public:
 #endif
 		ret.push_back("auto_recover_backup_interval");
 		ret.push_back("restrict_radius_ducks");
+		ret.push_back("resize_imported_images");
 		ret.push_back("browser_command");
 		ret.push_back("custom_filename_prefix");
 		ret.push_back("preferred_x_size");
 		ret.push_back("preferred_y_size");
-		ret.push_back("predefined_size");		
+		ret.push_back("predefined_size");
+		ret.push_back("preferred_fps");
+		ret.push_back("predefined_fps");
 		return ret;
 	}
 };
@@ -661,7 +728,7 @@ init_ui_manager()
 
 	Glib::RefPtr<Gtk::ActionGroup> toolbox_action_group = Gtk::ActionGroup::create("toolbox");
 
-	Glib::RefPtr<Gtk::ActionGroup> actions_action_group = Gtk::ActionGroup::create();
+	Glib::RefPtr<Gtk::ActionGroup> actions_action_group = Gtk::ActionGroup::create("actions");
 
 	menus_action_group->add( Gtk::Action::create("menu-file", _("_File")) );
 	menus_action_group->add( Gtk::Action::create("menu-edit", _("_Edit")) );
@@ -674,7 +741,7 @@ init_ui_manager()
 	menus_action_group->add( Gtk::Action::create("menu-layer-new", _("New Layer")) );
 	menus_action_group->add( Gtk::Action::create("menu-keyframe", _("Keyframe")) );
 	menus_action_group->add( Gtk::Action::create("menu-group", _("Group")) );
-	menus_action_group->add( Gtk::Action::create("menu-state", _("State")) );
+	menus_action_group->add( Gtk::Action::create("menu-state", _("Tool")) );
 	menus_action_group->add( Gtk::Action::create("menu-toolbox", _("Toolbox")) );
 
 	// Add the synfigapp actions...
@@ -979,7 +1046,7 @@ init_ui_manager()
 	}
 
 	// Add default keyboard accelerators
-#define ACCEL(path,accel)						\
+#define ACCEL(accel,path)						\
 	{											\
 		Gtk::AccelKey accel_key(accel,path);	\
 		Gtk::AccelMap::add_entry(accel_key.get_path(), accel_key.get_key(), accel_key.get_mod());	\
@@ -991,94 +1058,80 @@ init_ui_manager()
 		Gtk::AccelMap::add_entry(accel_key.get_path(), accel_key.get_key(), accel_key.get_mod());	\
 	}
 
-	ACCEL("<Actions>//select-all-ducks","<Control>a");
-	ACCEL("<Actions>//unselect-all-ducks","<Control>d");
-	ACCEL("<Actions>//select-all-layers","<Control><Shift>a");
-	ACCEL("<Actions>//unselect-all-layers","<Control><Shift>d");
-	ACCEL("<Actions>//render","F9");
-	ACCEL("<Actions>//preview","F11");
-	ACCEL("<Actions>//properties","F8");
-	ACCEL("<Actions>//options","F12");
-	ACCEL("<Actions>//import","<control>i");
-	ACCEL2(Gtk::AccelKey(GDK_Escape,static_cast<Gdk::ModifierType>(0),"<Actions>//stop"));
-	ACCEL("<Actions>//toggle-grid-show","<Control>g");
-	ACCEL("<Actions>//toggle-grid-snap","<Control>l");
-	ACCEL2(Gtk::AccelKey('`',Gdk::CONTROL_MASK,"<Actions>//toggle-low-res"));
-	ACCEL("<Actions>//mask-position-ducks", "<Mod1>1");
-	ACCEL("<Actions>//mask-vertex-ducks", "<Mod1>2");
-	ACCEL("<Actions>//mask-tangent-ducks", "<Mod1>3");
-	ACCEL("<Actions>//mask-radius-ducks", "<Mod1>4");
-	ACCEL("<Actions>//mask-width-ducks", "<Mod1>5");
-	ACCEL("<Actions>//mask-angle-ducks", "<Mod1>6");
+	// the toolbox
+	ACCEL("<Mod1>a",													"<Actions>/action_group_state_manager/state-normal"					);
+	ACCEL("<Mod1>v",													"<Actions>/action_group_state_manager/state-smooth_move"				);
+	ACCEL("<Mod1>s",													"<Actions>/action_group_state_manager/state-scale"					);
+	ACCEL("<Mod1>t",													"<Actions>/action_group_state_manager/state-rotate"					);
+	ACCEL("<Mod1>m",													"<Actions>/action_group_state_manager/state-mirror"					);
+	ACCEL("<Mod1>c",													"<Actions>/action_group_state_manager/state-circle"					);
+	ACCEL("<Mod1>r",													"<Actions>/action_group_state_manager/state-rectangle"				);
+	ACCEL("<Mod1>q",													"<Actions>/action_group_state_manager/state-star"						);
+	ACCEL("<Mod1>g",													"<Actions>/action_group_state_manager/state-gradient"					);
+	ACCEL("<Mod1>p",													"<Actions>/action_group_state_manager/state-polygon"					);
+	ACCEL("<Mod1>b",													"<Actions>/action_group_state_manager/state-bline"					);
+	ACCEL("<Mod1>x",													"<Actions>/action_group_state_manager/state-text"						);
+	ACCEL("<Mod1>f",													"<Actions>/action_group_state_manager/state-fill"						);
+	ACCEL("<Mod1>e",													"<Actions>/action_group_state_manager/state-eyedrop"					);
+	ACCEL("<Mod1>z",													"<Actions>/action_group_state_manager/state-zoom"						);
+	ACCEL("<Mod1>d",													"<Actions>/action_group_state_manager/state-draw"						);
+	ACCEL("<Mod1>k",													"<Actions>/action_group_state_manager/state-sketch"					);
+	ACCEL("<Mod1>w",													"<Actions>/action_group_state_manager/state-width"					);
 
-	ACCEL2(Gtk::AccelKey(GDK_Page_Up,Gdk::SHIFT_MASK,"<Actions>//action-layer_raise"));
-	ACCEL2(Gtk::AccelKey(GDK_Page_Down,Gdk::SHIFT_MASK,"<Actions>//action-layer_lower"));
-
-	ACCEL("<Actions>//quality-01","<Control>1");
-	ACCEL("<Actions>//quality-02","<Control>2");
-	ACCEL("<Actions>//quality-03","<Control>3");
-	ACCEL("<Actions>//quality-04","<Control>4");
-	ACCEL("<Actions>//quality-05","<Control>5");
-	ACCEL("<Actions>//quality-06","<Control>6");
-	ACCEL("<Actions>//quality-07","<Control>7");
-	ACCEL("<Actions>//quality-08","<Control>8");
-	ACCEL("<Actions>//quality-09","<Control>9");
-	ACCEL("<Actions>//quality-10","<Control>0");
-	ACCEL("<Actions>//undo","<Control>z");
-	ACCEL("<Actions>//redo","<Control>r");
-	ACCEL("<Actions>//action-layer_remove","Delete");
-
-/*	ACCEL2(Gtk::AccelKey(']',static_cast<Gdk::ModifierType>(0),"<Actions>//jump-next-keyframe"));
-	ACCEL2(Gtk::AccelKey('[',static_cast<Gdk::ModifierType>(0),"<Actions>//jump-prev-keyframe"));
-	ACCEL2(Gtk::AccelKey('=',static_cast<Gdk::ModifierType>(0),"<Actions>//canvas-zoom-in"));
-	ACCEL2(Gtk::AccelKey('-',static_cast<Gdk::ModifierType>(0),"<Actions>//canvas-zoom-out"));
-	ACCEL("<Actions>//time-zoom-in","+");
-	ACCEL("<Actions>//time-zoom-out","_");
-*/
-	ACCEL2(Gtk::AccelKey('(',Gdk::CONTROL_MASK,"<Actions>//decrease-low-res-pixel-size"));
-	ACCEL2(Gtk::AccelKey(')',Gdk::CONTROL_MASK,"<Actions>//increase-low-res-pixel-size"));
-
-	ACCEL2(Gtk::AccelKey('(',Gdk::MOD1_MASK|Gdk::CONTROL_MASK,"<Actions>//amount-dec"));
-	ACCEL2(Gtk::AccelKey(')',Gdk::MOD1_MASK|Gdk::CONTROL_MASK,"<Actions>//amount-inc"));
-
-	ACCEL2(Gtk::AccelKey(']',Gdk::CONTROL_MASK,"<Actions>//jump-next-keyframe"));
-	ACCEL2(Gtk::AccelKey('[',Gdk::CONTROL_MASK,"<Actions>//jump-prev-keyframe"));
-	ACCEL2(Gtk::AccelKey('=',Gdk::CONTROL_MASK,"<Actions>//canvas-zoom-in"));
-	ACCEL2(Gtk::AccelKey('-',Gdk::CONTROL_MASK,"<Actions>//canvas-zoom-out"));
-	ACCEL2(Gtk::AccelKey('+',Gdk::CONTROL_MASK,"<Actions>//time-zoom-in"));
-	ACCEL2(Gtk::AccelKey('_',Gdk::CONTROL_MASK,"<Actions>//time-zoom-out"));
-	ACCEL2(Gtk::AccelKey('.',Gdk::CONTROL_MASK,"<Actions>//seek-next-frame"));
-	ACCEL2(Gtk::AccelKey(',',Gdk::CONTROL_MASK,"<Actions>//seek-prev-frame"));
-	ACCEL2(Gtk::AccelKey('>',Gdk::CONTROL_MASK,"<Actions>//seek-next-second"));
-	ACCEL2(Gtk::AccelKey('<',Gdk::CONTROL_MASK,"<Actions>//seek-prev-second"));
-	ACCEL2(Gtk::AccelKey('o',Gdk::MOD1_MASK,"<Actions>//toggle-onion-skin"));
-	ACCEL("<Actions>//play",              "<Control>p");
-	ACCEL("<Actions>//seek-begin","Home");
-	ACCEL("<Actions>//seek-end","End");
-
-	ACCEL("<Actions>//state-normal",      "<Mod1>a");
-	ACCEL("<Actions>//state-smooth_move", "<Mod1>v");
-	ACCEL("<Actions>//state-scale",       "<Mod1>s");
-	ACCEL("<Actions>//state-rotate",      "<Mod1>t");
-	ACCEL("<Actions>//state-mirror",      "<Mod1>m");
-
-	ACCEL("<Actions>//state-circle",      "<Mod1>c");
-	ACCEL("<Actions>//state-rectangle",   "<Mod1>r");
-	ACCEL("<Actions>//state-star",        "<Mod1>q");
-	ACCEL("<Actions>//state-gradient",    "<Mod1>g");
-	ACCEL("<Actions>//state-polygon",     "<Mod1>p");
-
-	ACCEL("<Actions>//state-bline",       "<Mod1>b");
-	ACCEL("<Actions>//state-text",        "<Mod1>x");
-	ACCEL("<Actions>//state-fill",        "<Mod1>f");
-	ACCEL("<Actions>//state-eyedrop",     "<Mod1>e");
-	ACCEL("<Actions>//state-zoom",        "<Mod1>z");
-
-	ACCEL("<Actions>//state-draw",        "<Mod1>d");
-	ACCEL("<Actions>//state-sketch",      "<Mod1>k");
-	ACCEL("<Actions>//state-width",       "<Mod1>w");
-
-	ACCEL("<Actions>//canvas-zoom-fit","<Control><Shift>z");
+	// everything else
+	ACCEL("<Control>a",													"<Actions>/canvasview/select-all-ducks"				);
+	ACCEL("<Control>d",													"<Actions>/canvasview/unselect-all-ducks"				);
+	ACCEL("<Control><Shift>a",											"<Actions>/canvasview/select-all-layers"				);
+	ACCEL("<Control><Shift>d",											"<Actions>/canvasview/unselect-all-layers"			);
+	ACCEL("F9",															"<Actions>/canvasview/render"							);
+	ACCEL("F11",														"<Actions>/canvasview/preview"						);
+	ACCEL("F8",															"<Actions>/canvasview/properties"						);
+	ACCEL("F12",														"<Actions>/canvasview/options"						);
+	ACCEL("<control>i",													"<Actions>/canvasview/import"							);
+	ACCEL2(Gtk::AccelKey(GDK_Escape,static_cast<Gdk::ModifierType>(0),	"<Actions>/canvasview/stop"							));
+	ACCEL("<Control>g",													"<Actions>/canvasview/toggle-grid-show"				);
+	ACCEL("<Control>l",													"<Actions>/canvasview/toggle-grid-snap"				);
+	ACCEL2(Gtk::AccelKey('`',Gdk::CONTROL_MASK,							"<Actions>/canvasview/toggle-low-res"					));
+	ACCEL("<Mod1>1",													"<Actions>/canvasview/mask-position-ducks"			);
+	ACCEL("<Mod1>2",													"<Actions>/canvasview/mask-vertex-ducks"				);
+	ACCEL("<Mod1>3",													"<Actions>/canvasview/mask-tangent-ducks"				);
+	ACCEL("<Mod1>4",													"<Actions>/canvasview/mask-radius-ducks"				);
+	ACCEL("<Mod1>5",													"<Actions>/canvasview/mask-width-ducks"				);
+	ACCEL("<Mod1>6",													"<Actions>/canvasview/mask-angle-ducks"				);
+	ACCEL2(Gtk::AccelKey(GDK_Page_Up,Gdk::SHIFT_MASK,					"<Actions>/action_group_layer_action_manager/action-LayerRaise"				));
+	ACCEL2(Gtk::AccelKey(GDK_Page_Down,Gdk::SHIFT_MASK,					"<Actions>/action_group_layer_action_manager/action-LayerLower"				));
+	ACCEL("<Control>1",													"<Actions>/canvasview/quality-01"						);
+	ACCEL("<Control>2",													"<Actions>/canvasview/quality-02"						);
+	ACCEL("<Control>3",													"<Actions>/canvasview/quality-03"						);
+	ACCEL("<Control>4",													"<Actions>/canvasview/quality-04"						);
+	ACCEL("<Control>5",													"<Actions>/canvasview/quality-05"						);
+	ACCEL("<Control>6",													"<Actions>/canvasview/quality-06"						);
+	ACCEL("<Control>7",													"<Actions>/canvasview/quality-07"						);
+	ACCEL("<Control>8",													"<Actions>/canvasview/quality-08"						);
+	ACCEL("<Control>9",													"<Actions>/canvasview/quality-09"						);
+	ACCEL("<Control>0",													"<Actions>/canvasview/quality-10"						);
+	ACCEL("<Control>z",													"<Actions>/action_group_dock_history/undo"							);
+	ACCEL("<Control>r",													"<Actions>/action_group_dock_history/redo"							);
+	ACCEL2(Gtk::AccelKey(GDK_Delete,Gdk::CONTROL_MASK,					"<Actions>/action_group_layer_action_manager/action-LayerRemove"				));
+	ACCEL2(Gtk::AccelKey('(',Gdk::CONTROL_MASK,							"<Actions>/canvasview/decrease-low-res-pixel-size"	));
+	ACCEL2(Gtk::AccelKey(')',Gdk::CONTROL_MASK,							"<Actions>/canvasview/increase-low-res-pixel-size"	));
+	ACCEL2(Gtk::AccelKey('(',Gdk::MOD1_MASK|Gdk::CONTROL_MASK,			"<Actions>/action_group_layer_action_manager/amount-dec"						));
+	ACCEL2(Gtk::AccelKey(')',Gdk::MOD1_MASK|Gdk::CONTROL_MASK,			"<Actions>/action_group_layer_action_manager/amount-inc"						));
+	ACCEL2(Gtk::AccelKey(']',Gdk::CONTROL_MASK,							"<Actions>/canvasview/jump-next-keyframe"				));
+	ACCEL2(Gtk::AccelKey('[',Gdk::CONTROL_MASK,							"<Actions>/canvasview/jump-prev-keyframe"				));
+	ACCEL2(Gtk::AccelKey('=',Gdk::CONTROL_MASK,							"<Actions>/canvasview/canvas-zoom-in"					));
+	ACCEL2(Gtk::AccelKey('-',Gdk::CONTROL_MASK,							"<Actions>/canvasview/canvas-zoom-out"				));
+	ACCEL2(Gtk::AccelKey('+',Gdk::CONTROL_MASK,							"<Actions>/canvasview/time-zoom-in"					));
+	ACCEL2(Gtk::AccelKey('_',Gdk::CONTROL_MASK,							"<Actions>/canvasview/time-zoom-out"					));
+	ACCEL2(Gtk::AccelKey('.',Gdk::CONTROL_MASK,							"<Actions>/canvasview/seek-next-frame"				));
+	ACCEL2(Gtk::AccelKey(',',Gdk::CONTROL_MASK,							"<Actions>/canvasview/seek-prev-frame"				));
+	ACCEL2(Gtk::AccelKey('>',Gdk::CONTROL_MASK,							"<Actions>/canvasview/seek-next-second"				));
+	ACCEL2(Gtk::AccelKey('<',Gdk::CONTROL_MASK,							"<Actions>/canvasview/seek-prev-second"				));
+	ACCEL("<Mod1>o",													"<Actions>/canvasview/toggle-onion-skin"				);
+	ACCEL("<Control><Shift>z",											"<Actions>/canvasview/canvas-zoom-fit"				);
+	ACCEL("<Control>p",													"<Actions>/canvasview/play"							);
+	ACCEL("Home",														"<Actions>/canvasview/seek-begin"						);
+	ACCEL("End",														"<Actions>/canvasview/seek-end"						);
 
 #undef ACCEL
 }
@@ -1143,6 +1196,11 @@ App::App(int *argc, char ***argv):
 
 	// Initialize the Synfig library
 	try { synfigapp_main=etl::smart_ptr<synfigapp::Main>(new synfigapp::Main(etl::dirname((*argv)[0]),&synfig_init_cb)); }
+	catch(std::runtime_error x)
+	{
+		get_ui_interface()->error(strprintf("%s\n\n%s", _("Failed to initialize synfig!"), x.what()));
+		throw;
+	}
 	catch(...)
 	{
 		get_ui_interface()->error(_("Failed to initialize synfig!"));
@@ -1268,7 +1326,7 @@ App::App(int *argc, char ***argv):
 		studio_init_cb.task(_("Init Input Dialog..."));
 		dialog_input=new Gtk::InputDialog();
 		dialog_input->get_close_button()->signal_clicked().connect( sigc::mem_fun( *dialog_input, &Gtk::InputDialog::hide ) );
-		dialog_input->get_save_button()->signal_clicked().connect( sigc::ptr_fun(studio::App::dialog_not_implemented) );
+		dialog_input->get_save_button()->signal_clicked().connect( sigc::mem_fun( *device_tracker, &DeviceTracker::save_preferences) );
 
 		studio_init_cb.task(_("Init auto recovery..."));
 		auto_recover=new AutoRecover();
@@ -1276,6 +1334,8 @@ App::App(int *argc, char ***argv):
 		studio_init_cb.amount_complete(9250,10000);
 		studio_init_cb.task(_("Loading Settings..."));
 		load_settings();
+		device_tracker->load_preferences();
+
 		studio_init_cb.task(_("Checking auto-recover..."));
 
 		studio_init_cb.amount_complete(9900,10000);
@@ -1284,12 +1344,13 @@ App::App(int *argc, char ***argv):
 		if(auto_recover->recovery_needed())
 		{
 			splash_screen.hide();
-			if (get_ui_interface()->yes_no(_("Auto Recovery"),
-										   _("Synfig Studio seems to have crashed\n"
-											 "before you could save all your files.\n"
-											 "Would you like to re-open those files\n"
-											 "and recover your unsaved changes?")) ==
-				synfigapp::UIInterface::RESPONSE_YES)
+			if (get_ui_interface()->confirmation("Crash Recovery",
+					_("Auto recovery file found"),
+					_("Synfig Studio seems to have crashed\n"
+					  "before you could save all your files.\n"
+					  "Recover unsaved changes?"),
+					_("Recover"), _("Ignore"))
+				== synfigapp::UIInterface::RESPONSE_OK)
 			{
 				int number_recovered;
 				if(!auto_recover->recover(number_recovered))
@@ -1364,7 +1425,7 @@ App::~App()
 	delete auto_recover;
 
 	delete about;
-	
+
 	toolbox->hide();
 
 //	studio::App::iteration(false);
@@ -1432,7 +1493,8 @@ App::set_recent_file_window_size(etl::handle<Instance> instance)
 		// find the canvas
 		synfig::Canvas::Handle canvas;
 		try {
-			canvas = instance->get_canvas()->find_canvas(String(canvas_window_size, current, separator-current));
+			String warnings;
+			canvas = instance->get_canvas()->find_canvas(String(canvas_window_size, current, separator-current), warnings);
 		}
 		catch(Exception::IDNotFound) {
 			// can't find the canvas; skip to the next canvas or return
@@ -1727,10 +1789,13 @@ App::reset_initial_window_configuration()
 	synfigapp::Main::settings().set_value("pref.single_threaded","0");
 #endif
 	synfigapp::Main::settings().set_value("pref.restrict_radius_ducks","0");
+	synfigapp::Main::settings().set_value("pref.resize_imported_images","0");
 	synfigapp::Main::settings().set_value("pref.custom_filename_prefix",DEFAULT_FILENAME_PREFIX);
 	synfigapp::Main::settings().set_value("pref.preferred_x_size","480");
 	synfigapp::Main::settings().set_value("pref.preferred_y_size","270");
 	synfigapp::Main::settings().set_value("pref.predefined_size",DEFAULT_PREDEFINED_SIZE);
+	synfigapp::Main::settings().set_value("pref.preferred_fps","24.0");
+	synfigapp::Main::settings().set_value("pref.predefined_fps",DEFAULT_PREDEFINED_FPS);
 	synfigapp::Main::settings().set_value("window.toolbox.pos","4 4");
 }
 
@@ -2215,7 +2280,7 @@ try_open_url(const std::string &url)
 			try { Glib::spawn_async(".", command_line, Glib::SPAWN_SEARCH_PATH); }
 			// Failed, move on to the next one
 			catch(Glib::SpawnError& exception){ continue; }
-			return true; // No exception means we succeeded!			
+			return true; // No exception means we succeeded!
 		}
 	}
 
@@ -2339,8 +2404,9 @@ App::open_as(std::string filename,std::string as)
 	try
 	{
 		OneMoment one_moment;
+		String errors, warnings;
 
-		etl::handle<synfig::Canvas> canvas(open_canvas_as(filename,as));
+		etl::handle<synfig::Canvas> canvas(open_canvas_as(filename,as,errors,warnings));
 		if(canvas && get_instance(canvas))
 		{
 			get_instance(canvas)->find_canvas_view(canvas)->present();
@@ -2350,7 +2416,10 @@ App::open_as(std::string filename,std::string as)
 		else
 		{
 			if(!canvas)
-				throw (String)strprintf(_("Unable to open file \"%s\""),filename.c_str());
+				throw (String)strprintf(_("Unable to load \"%s\":\n\n"),filename.c_str()) + errors;
+
+			if (warnings != "")
+				dialog_warning_blocking(_("Warnings"), strprintf("%s:\n\n%s", _("Warnings"), warnings.c_str()));
 
 			if (as.find(custom_filename_prefix.c_str()) != 0)
 				add_recent_file(as);
@@ -2373,6 +2442,11 @@ App::open_as(std::string filename,std::string as)
 		dialog_error_blocking(_("Error"), x);
 		return false;
 	}
+	catch(runtime_error x)
+	{
+		dialog_error_blocking(_("Error"), x.what());
+		return false;
+	}
 	catch(...)
 	{
 		dialog_error_blocking(_("Error"), _("Uncaught error on file open (BUG)"));
@@ -2392,7 +2466,7 @@ App::new_instance()
 	canvas->set_name(file_name);
 	file_name += ".sifz";
 
-	canvas->rend_desc().set_frame_rate(24.0);
+	canvas->rend_desc().set_frame_rate(preferred_fps);
 	canvas->rend_desc().set_time_start(0.0);
 	canvas->rend_desc().set_time_end(5.0);
 	canvas->rend_desc().set_x_res(DPI2DPM(72.0f));
