@@ -2,7 +2,7 @@
 /*!	\file cellrenderer_timetrack.cpp
 **	\brief Template Header
 **
-**	$Id: cellrenderer_timetrack.cpp 1904 2008-03-09 12:55:59Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -824,15 +824,15 @@ CellRenderer_TimeTrack::activate_vfunc(
 					if(mode & COPY_MASK) //copy
 					{
 						etl::handle<studio::Instance>::cast_static(canvas_interface()->get_instance())
-							->process_action("timepoint_copy", param_list);
+							->process_action("TimepointsCopy", param_list);
 					}else if(delmode) //DELETE
 					{
 						etl::handle<studio::Instance>::cast_static(canvas_interface()->get_instance())
-							->process_action("timepoint_delete", param_list);
+							->process_action("TimepointsDelete", param_list);
 					}else //MOVE
 					{
 						etl::handle<studio::Instance>::cast_static(canvas_interface()->get_instance())
-							->process_action("timepoint_move", param_list);
+							->process_action("TimepointsMove", param_list);
 					}
 
 					//now replace all the selected with the new selected
