@@ -2,7 +2,7 @@
 /*!	\file cellrenderer_value.cpp
 **	\brief Template File
 **
-**	$Id: cellrenderer_value.cpp 1734 2008-02-17 13:01:34Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -509,6 +509,7 @@ CellRenderer_ValueBase::start_editing_vfunc(
 	const Gdk::Rectangle& cell_area __attribute__ ((unused)),
 	Gtk::CellRendererState flags __attribute__ ((unused)))
 {
+	edit_value_done_called = false;
 	// If we aren't editable, then there is nothing to do
 	if(!property_editable())
 		return 0;
@@ -533,6 +534,7 @@ CellRenderer_ValueBase::start_editing_vfunc(
 				path
 			)
 		);
+		App::dialog_gradient->grab_button_set_sensitive(true);
 		App::dialog_gradient->present();
 
 		return NULL;
@@ -580,6 +582,14 @@ CellRenderer_ValueBase::start_editing_vfunc(
 void
 CellRenderer_ValueBase::on_value_editing_done()
 {
+	if (edit_value_done_called)
+	{
+		synfig::error("on_value_editing_done(): Called twice!");
+		return;
+	}
+
+	edit_value_done_called = true;
+
 	if(value_entry)
 	{
 		ValueBase old_value(property_value_.get_value());
