@@ -2,7 +2,7 @@
 /*!	\file childrentreestore.cpp
 **	\brief Template File
 **
-**	$Id: childrentreestore.cpp 1511 2008-01-27 12:16:51Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -384,6 +384,6 @@ ChildrenTreeStore::set_value_impl(const Gtk::TreeModel::iterator& iter, int colu
 	}
 	catch(std::exception x)
 	{
-		g_warning(x.what());
+		g_warning("%s", x.what());
 	}
 }
