@@ -2,7 +2,7 @@
 /*!	\file dialog_color.h
 **	\brief Template Header
 **
-**	$Id: dialog_color.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -28,22 +28,11 @@
 /* === H E A D E R S ======================================================= */
 
 #include <gtk/gtk.h>
-#include <gtkmm/adjustment.h>
-#include <gtkmm/table.h>
-#include <gtkmm/button.h>
 #include <gtkmm/dialog.h>
-#include <gtkmm/drawingarea.h>
-#include <gtkmm/optionmenu.h>
-#include <gtkmm/checkbutton.h>
-
-#include <synfig/gamma.h>
-#include <synfig/time.h>
+#include <gtkmm/tooltips.h>
+#include <sigc++/functors/slot.h>
 
 #include "widget_coloredit.h"
-
-#include <synfigapp/value_desc.h>
-#include <synfig/time.h>
-
 #include "dialogsettings.h"
 
 /* === M A C R O S ========================================================= */
@@ -52,12 +41,6 @@
 
 /* === C L A S S E S & S T R U C T S ======================================= */
 
-namespace Gtk { class Menu; class SpinButton; class Adjustment; };
-
-namespace synfigapp {
-class CanvasInterface;
-};
-
 namespace studio {
 
 class Widget_Color;
@@ -65,36 +48,37 @@ class Widget_Color;
 class Dialog_Color : public Gtk::Dialog
 {
 	DialogSettings dialog_settings;
+	Gtk::Tooltips tooltips;
+
+	Widget_ColorEdit* color_edit_widget;
 
 	sigc::signal<void,synfig::Color> signal_edited_;
-	//sigc::signal<void,synfig::Color> signal_apply_;
-
-	bool on_close_pressed();
-	void on_apply_pressed();
-	void on_color_changed();
-
-	Widget_ColorEdit* widget_color;
 
 	bool busy_;
 
+	void create_color_edit_widget();
+	void create_set_color_button(const char *stock_id,
+			const Glib::ustring& tip_text, int index,
+			const sigc::slot0<void>& callback);
+	void create_close_button();
+
+	void on_color_changed();
+	void on_set_oc_pressed();
+	void on_set_fc_pressed();
+	bool on_close_pressed();
+
 public:
-	bool busy()const { return busy_; }
-
-	sigc::signal<void,synfig::Color>& signal_edited() { return signal_edited_; }
-
-	//sigc::signal<void,synfig::Color>& signal_apply() { return signal_apply_; }
-
-	void set_color(const synfig::Color& x) { widget_color->set_value(x); }
-
-	synfig::Color get_color()const { return widget_color->get_value(); }
-
-	void reset();
-
-
 	Dialog_Color();
 	~Dialog_Color();
 
-//	void edit(const synfigapp::ValueDesc &x, etl::handle<synfigapp::CanvasInterface> canvas_interface, synfig::Time x=0);
+	sigc::signal<void,synfig::Color>& signal_edited() { return signal_edited_; }
+
+	void set_color(const synfig::Color& x) { color_edit_widget->set_value(x); }
+	synfig::Color get_color() const { return color_edit_widget->get_value(); }
+	void reset();
+
+	bool busy() const { return busy_; }
+
 }; // END of Dialog_Color
 
 }; // END of namespace studio
