@@ -2,12 +2,12 @@
 /*!	\file dialog_setup.cpp
 **	\brief Template File
 **
-**	$Id: dialog_setup.cpp 2108 2008-10-19 02:30:40Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
-**  Copyright (c) 2008 Carlos López
+**	Copyright (c) 2008, 2009 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -37,7 +37,6 @@
 #include <gtkmm/table.h>
 #include <gtkmm/frame.h>
 #include <gtkmm/notebook.h>
-#include <gtkmm/spinbutton.h>
 #include "widget_enum.h"
 #include "autorecover.h"
 
@@ -82,9 +81,11 @@ Dialog_Setup::Dialog_Setup():
 	toggle_single_threaded(_("Use Only a Single Thread")),
 #endif
 	toggle_restrict_radius_ducks(_("Restrict Real-Valued Ducks to Top Right Quadrant")),
+	toggle_resize_imported_images(_("Scale New Imported Images to Fit Canvas")),
 	adj_pref_x_size(480,1,10000,1,10,0),
-	adj_pref_y_size(270,1,10000,1,10,0)
-	
+	adj_pref_y_size(270,1,10000,1,10,0),
+	adj_pref_fps(24.0,1.0,100,0.1,1,0)
+
 	{
 	// Setup the buttons
 
@@ -210,38 +211,41 @@ Dialog_Setup::Dialog_Setup():
 	// Misc - restrict_radius_ducks
 	misc_table->attach(toggle_restrict_radius_ducks, 0, 2, 8, 9, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
 
+	// Misc - resize_imported_images
+	misc_table->attach(toggle_resize_imported_images, 0, 2, 9, 10, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
+
 	// Misc - browser_command
 	attach_label(misc_table, _("Browser Command"), 4, xpadding, ypadding);
 	misc_table->attach(textbox_browser_command, 1, 2, 4, 5, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
 
 	// Document
-	Gtk::Table *document_table=manage(new Gtk::Table(2,4,false));
-	notebook->append_page(*document_table,_("Document"));
+	Gtk::Table *document_table = manage(new Gtk::Table(2, 4, false));
+	notebook->append_page(*document_table, _("Document"));
 
 	// Document - Preferred file name prefix
 	attach_label(document_table, _("New Document filename prefix"), 0, xpadding, ypadding);
 	document_table->attach(textbox_custom_filename_prefix, 1, 4, 0, 1, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
-	tooltips_.set_tip(textbox_custom_filename_prefix,_("File name prefix for the new created document"));
+	tooltips_.set_tip(textbox_custom_filename_prefix, _("File name prefix for the new created document"));
 
 	// Document - New Document X size
-	Gtk::SpinButton* pref_x_size_spinbutton(manage(new Gtk::SpinButton(adj_pref_x_size,1,0)));
-	attach_label(document_table,_("New Document X size"),1, xpadding, ypadding);
-	document_table->attach(*pref_x_size_spinbutton, 1, 2, 1, 2,Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding); 
-	tooltips_.set_tip(*pref_x_size_spinbutton,_("Width in pixels of the new created document"));
-	
+	pref_x_size_spinbutton = Gtk::manage(new Gtk::SpinButton(adj_pref_x_size, 1, 0));
+	attach_label(document_table, _("New Document X size"),1, xpadding, ypadding);
+	document_table->attach(*pref_x_size_spinbutton, 1, 2, 1, 2, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
+	tooltips_.set_tip(*pref_x_size_spinbutton, _("Width in pixels of the new created document"));
+
 	// Document - New Document Y size
-	Gtk::SpinButton* pref_y_size_spinbutton(manage(new Gtk::SpinButton(adj_pref_y_size,1,0)));
-	attach_label(document_table,_("New Document Y size"),2, xpadding, ypadding);
-	document_table->attach(*pref_y_size_spinbutton, 1, 2, 2, 3,Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding); 
-	tooltips_.set_tip(*pref_y_size_spinbutton,_("High in pixels of the new created document"));
+	pref_y_size_spinbutton = Gtk::manage(new Gtk::SpinButton(adj_pref_y_size, 1, 0));
+	attach_label(document_table,_("New Document Y size"), 2, xpadding, ypadding);
+	document_table->attach(*pref_y_size_spinbutton, 1, 2, 2, 3,Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
+	tooltips_.set_tip(*pref_y_size_spinbutton, _("High in pixels of the new created document"));
 
 	//Document - Template for predefined sizes of canvases.
-	size_template_combo=Gtk::manage(new Gtk::ComboBoxText());
+	size_template_combo = Gtk::manage(new Gtk::ComboBoxText());
 	Gtk::Label* label(manage(new Gtk::Label(_("Predefined Resolutions:"))));
 	label->set_alignment(Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER);
 	document_table->attach(*label, 2, 3, 1, 2, Gtk::SHRINK|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
-	document_table->attach(*size_template_combo,2, 3, 2, 3, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
-	size_template_combo->signal_changed().connect(sigc::mem_fun(*this,&studio::Dialog_Setup::on_size_template_combo_change));
+	document_table->attach(*size_template_combo, 2, 3, 2, 3, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
+	size_template_combo->signal_changed().connect(sigc::mem_fun(*this, &studio::Dialog_Setup::on_size_template_combo_change));
 	size_template_combo->prepend_text(_("4096x3112 Full Aperture 4K"));
 	size_template_combo->prepend_text(_("2048x1556 Full Aperture Native 2K"));
 	size_template_combo->prepend_text(_("1920x1080 HDTV 1080p/i"));
@@ -258,6 +262,34 @@ Dialog_Setup::Dialog_Setup():
 	size_template_combo->prepend_text(_("360x203   Web 360x HD"));
 	size_template_combo->prepend_text(DEFAULT_PREDEFINED_SIZE);
 
+	//Document - Template for predefined fps
+	fps_template_combo = Gtk::manage(new Gtk::ComboBoxText());
+	Gtk::Label* label1(manage(new Gtk::Label(_("Predefined FPS:"))));
+	label1->set_alignment(Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER);
+	document_table->attach(*label1, 2, 3, 3, 4, Gtk::SHRINK|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
+	document_table->attach(*fps_template_combo,2, 3, 4, 5, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
+	fps_template_combo->signal_changed().connect(sigc::mem_fun(*this, &studio::Dialog_Setup::on_fps_template_combo_change));
+	//Document - Fill the FPS combo box with proper strings (not localised)
+	float f[8];
+	f[0] = 60;
+	f[1] = 50;
+	f[2] = 30;
+	f[3] = 25;
+	f[4] = 24.967;
+	f[5] = 24;
+	f[6] = 15;
+	f[7] = 12;
+	for (int i=0; i<8; i++)
+		fps_template_combo->prepend_text(strprintf("%5.3f", f[i]));
+
+	fps_template_combo->prepend_text(DEFAULT_PREDEFINED_FPS);
+
+	// Document - New Document FPS
+	pref_fps_spinbutton = Gtk::manage(new Gtk::SpinButton(adj_pref_fps, 1, 3));
+	attach_label(document_table,_("New Document FPS"), 4, xpadding, ypadding);
+	document_table->attach(*pref_fps_spinbutton, 1, 2, 4, 5, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
+	tooltips_.set_tip(*pref_fps_spinbutton, _("Frames per second of the new created document"));
+
 	show_all_children();
 }
 
@@ -298,6 +330,9 @@ Dialog_Setup::on_apply_pressed()
 	// Set the restrict_radius_ducks flag
 	App::restrict_radius_ducks=toggle_restrict_radius_ducks.get_active();
 
+	// Set the resize_imported_images flag
+	App::resize_imported_images=toggle_resize_imported_images.get_active();
+
 	// Set the browser_command textbox
 	App::browser_command=textbox_browser_command.get_text();
 
@@ -309,10 +344,16 @@ Dialog_Setup::on_apply_pressed()
 
 	// Set the preferred new Document Y dimension
 	App::preferred_y_size=int(adj_pref_y_size.get_value());
-	
+
 	// Set the preferred Predefined size
 	App::predefined_size=size_template_combo->get_active_text();
 
+	// Set the preferred Predefined fps
+	App::predefined_fps=fps_template_combo->get_active_text();
+
+	// Set the preferred FPS
+	App::preferred_fps=Real(adj_pref_fps.get_value());
+
 	App::save_settings();
 }
 
@@ -360,8 +401,10 @@ void
 Dialog_Setup::on_size_template_combo_change()
 {
 	String selection(size_template_combo->get_active_text());
-	if(selection==DEFAULT_PREDEFINED_SIZE) 
+	if(selection==DEFAULT_PREDEFINED_SIZE)
 	{
+		pref_y_size_spinbutton->set_sensitive(true);
+		pref_x_size_spinbutton->set_sensitive(true);
 		return;
 	}
 	String::size_type locx=selection.find_first_of("x"); // here should be some comparison with string::npos
@@ -372,6 +415,23 @@ Dialog_Setup::on_size_template_combo_change()
 	int y=atoi(y_size.c_str());
 	adj_pref_x_size.set_value(x);
 	adj_pref_y_size.set_value(y);
+	pref_y_size_spinbutton->set_sensitive(false);
+	pref_x_size_spinbutton->set_sensitive(false);
+
+	return;
+}
+
+void
+Dialog_Setup::on_fps_template_combo_change()
+{
+	String selection(fps_template_combo->get_active_text());
+	if(selection==DEFAULT_PREDEFINED_FPS)
+	{
+		pref_fps_spinbutton->set_sensitive(true);
+		return;
+	}
+	adj_pref_fps.set_value(atof(selection.c_str()));
+	pref_fps_spinbutton->set_sensitive(false);
 	return;
 }
 
@@ -415,6 +475,9 @@ Dialog_Setup::refresh()
 	// Refresh the status of the restrict_radius_ducks flag
 	toggle_restrict_radius_ducks.set_active(App::restrict_radius_ducks);
 
+	// Refresh the status of the resize_imported_images flag
+	toggle_resize_imported_images.set_active(App::resize_imported_images);
+
 	// Refresh the browser_command textbox
 	textbox_browser_command.set_text(App::browser_command);
 
@@ -423,12 +486,18 @@ Dialog_Setup::refresh()
 
 	// Refresh the preferred new Document X dimension
 	adj_pref_x_size.set_value(App::preferred_x_size);
-	
+
 	// Refresh the preferred new Document Y dimension
 	adj_pref_y_size.set_value(App::preferred_y_size);
-	
+
 	// Refresh the preferred Predefined size
 	size_template_combo->set_active_text(App::predefined_size);
+
+	//Refresh the preferred FPS
+	adj_pref_fps.set_value(App::preferred_fps);
+
+	//Refresh the predefined FPS
+	fps_template_combo->set_active_text(App::predefined_fps);
 }
 
 GammaPattern::GammaPattern():
