@@ -2,12 +2,12 @@
 /*!	\file dialog_setup.h
 **	\brief Template Header
 **
-**	$Id: dialog_setup.h 2098 2008-10-14 21:00:21Z genete $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
-**  Copyright (c) 2008 Carlos López
+**	Copyright (c) 2008, 2009 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -40,6 +40,7 @@
 #include <gtkmm/widget_time.h>
 #include <gtkmm/tooltips.h>
 #include <gtkmm/comboboxtext.h>
+#include <gtkmm/spinbutton.h>
 
 #include <synfig/gamma.h>
 #include <synfig/time.h>
@@ -49,6 +50,10 @@
 #ifndef DEFAULT_PREDEFINED_SIZE
 #define DEFAULT_PREDEFINED_SIZE _("Custom Size")
 #endif
+#ifndef DEFAULT_PREDEFINED_FPS
+#define DEFAULT_PREDEFINED_FPS _("Custom fps")
+#endif
+
 /* === T Y P E D E F S ===================================================== */
 
 /* === C L A S S E S & S T R U C T S ======================================= */
@@ -156,6 +161,7 @@ class Dialog_Setup : public Gtk::Dialog
 	void on_black_level_change();
 	void on_red_blue_level_change();
 	void on_size_template_combo_change();
+	void on_fps_template_combo_change();
 
 	GammaPattern gamma_pattern;
 	BlackLevelSelector black_level_selector;
@@ -182,13 +188,19 @@ class Dialog_Setup : public Gtk::Dialog
 	Widget_Time auto_backup_interval;
 
 	Gtk::CheckButton toggle_restrict_radius_ducks;
+	Gtk::CheckButton toggle_resize_imported_images;
 
 	Gtk::Entry textbox_browser_command;
-	
+
 	Gtk::ComboBoxText* size_template_combo;
+	Gtk::ComboBoxText* fps_template_combo;
 	Gtk::Entry textbox_custom_filename_prefix;
 	Gtk::Adjustment adj_pref_x_size;
 	Gtk::Adjustment adj_pref_y_size;
+	Gtk::Adjustment adj_pref_fps;
+	Gtk::SpinButton* pref_fps_spinbutton;
+	Gtk::SpinButton* pref_y_size_spinbutton;
+	Gtk::SpinButton* pref_x_size_spinbutton;
 	Gtk::Tooltips tooltips_;
 public:
 
