@@ -2,7 +2,7 @@
 /*!	\file dock_layers.cpp
 **	\brief Template File
 **
-**	$Id: dock_layers.cpp 1755 2008-02-19 10:31:20Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -77,8 +77,8 @@ Dock_Layers::Dock_Layers():
 {
 	if(layer_action_manager)layer_action_manager->set_ui_manager(App::ui_manager());
 
-	action_group_new_layers=Gtk::ActionGroup::create();
-	action_group_layer_ops=Gtk::ActionGroup::create();
+	action_group_new_layers=Gtk::ActionGroup::create("action_group_new_layers");
+	action_group_layer_ops=Gtk::ActionGroup::create("action_group_layer_ops");
 
 	std::map<synfig::String,synfig::String> category_map;
 
@@ -149,13 +149,13 @@ Dock_Layers::Dock_Layers():
     Glib::ustring ui_info =
 	"<ui>"
 	"	<toolbar action='toolbar-layer'>"
-	"	<toolitem action='action-layer_raise' />"
-	"	<toolitem action='action-layer_lower' />"
+	"	<toolitem action='action-LayerRaise' />"
+	"	<toolitem action='action-LayerLower' />"
 	"	<separator />"
-	"	<toolitem action='action-layer_duplicate' />"
-	"	<toolitem action='action-layer_encapsulate' />"
+	"	<toolitem action='action-LayerDuplicate' />"
+	"	<toolitem action='action-LayerEncapsulate' />"
 	"	<toolitem action='select-all-child-layers' />"
-	"	<toolitem action='action-layer_remove' />"
+	"	<toolitem action='action-LayerRemove' />"
 	"	<separator />"
 	"	<toolitem action='cut' />"
 	"	<toolitem action='copy' />"
