@@ -2,7 +2,7 @@
 /*!	\file dock_timetrack.cpp
 **	\brief Template File
 **
-**	$Id: dock_timetrack.cpp 1724 2008-02-17 09:06:45Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -43,6 +43,7 @@
 #include "layerparamtreestore.h"
 #include "workarea.h"
 #include "widget_timeslider.h"
+#include "widget_keyframe_list.h"
 #include "layerparamtreestore.h"
 #include "general.h"
 #include <synfig/timepointcollect.h>
@@ -318,7 +319,7 @@ public:
 		param_list.add("waypoint",waypoint);
 	//	param_list.add("time",canvas_interface()->get_time());
 
-		etl::handle<studio::Instance>::cast_static(param_tree_store_->canvas_interface()->get_instance())->process_action("waypoint_set_smart", param_list);
+		etl::handle<studio::Instance>::cast_static(param_tree_store_->canvas_interface()->get_instance())->process_action("WaypointSetSmart", param_list);
 	}
 
 	void mimic(Gtk::TreeView *param_tree_view)
@@ -363,7 +364,7 @@ public:
 				row_height = atoi(getenv("SYNFIG_TIMETRACK_ROW_HEIGHT"));
 			if (row_height < 3)
 				row_height = 18;
-									  
+
 			cellrenderer_time_track->set_fixed_size(-1,row_height);
 		}
 	}
@@ -405,14 +406,17 @@ Dock_Timetrack::Dock_Timetrack():
 {
 	table_=0;
 	widget_timeslider_= new Widget_Timeslider();
+	widget_kf_list_= new Widget_Keyframe_List();
 
 	int header_height = 0;
 	if(getenv("SYNFIG_TIMETRACK_HEADER_HEIGHT"))
 		header_height = atoi(getenv("SYNFIG_TIMETRACK_HEADER_HEIGHT"));
 	if (header_height < 3)
-		header_height = 22;
+		header_height = 24;
+
+	widget_timeslider_->set_size_request(-1,header_height-header_height/3+1);
+	widget_kf_list_->set_size_request(-1,header_height/3+1);
 
-	widget_timeslider_->set_size_request(-1,header_height);
 	hscrollbar_=new Gtk::HScrollbar();
 	vscrollbar_=new Gtk::VScrollbar();
 }
@@ -423,6 +427,7 @@ Dock_Timetrack::~Dock_Timetrack()
 	delete hscrollbar_;
 	delete vscrollbar_;
 	delete widget_timeslider_;
+	delete widget_kf_list_;
 }
 
 void
@@ -493,17 +498,22 @@ Dock_Timetrack::changed_canvas_view_vfunc(etl::loose_handle<CanvasView> canvas_v
 
 		assert(tree_view);
 
+
 		widget_timeslider_->set_time_adjustment(&canvas_view->time_adjustment());
 		widget_timeslider_->set_bounds_adjustment(&canvas_view->time_window_adjustment());
 		widget_timeslider_->set_global_fps(canvas_view->get_canvas()->rend_desc().get_frame_rate());
 
+		widget_kf_list_->set_time_adjustment(&canvas_view->time_adjustment());
+		widget_kf_list_->set_canvas_interface(canvas_view->canvas_interface());
+
 		vscrollbar_->set_adjustment(*tree_view->get_vadjustment());
 		hscrollbar_->set_adjustment(canvas_view->time_window_adjustment());
-		table_=new Gtk::Table(2,2);
-		table_->attach(*widget_timeslider_, 0, 1, 0, 1, Gtk::FILL|Gtk::EXPAND, Gtk::FILL|Gtk::SHRINK);
-		table_->attach(*tree_view, 0, 1, 1, 2, Gtk::FILL|Gtk::EXPAND, Gtk::FILL|Gtk::EXPAND);
-		table_->attach(*hscrollbar_, 0, 1, 2, 3, Gtk::FILL|Gtk::EXPAND, Gtk::FILL|Gtk::SHRINK);
-		table_->attach(*vscrollbar_, 1, 2, 0, 2, Gtk::FILL|Gtk::SHRINK, Gtk::FILL|Gtk::EXPAND);
+		table_=new Gtk::Table(2,3);
+		table_->attach(*widget_timeslider_, 0, 1, 1, 2, Gtk::FILL|Gtk::SHRINK, Gtk::FILL|Gtk::SHRINK);
+		table_->attach(*widget_kf_list_, 0, 1, 0, 1, Gtk::FILL|Gtk::EXPAND, Gtk::FILL|Gtk::SHRINK);
+		table_->attach(*tree_view, 0, 1, 2, 3, Gtk::FILL|Gtk::EXPAND, Gtk::FILL|Gtk::EXPAND);
+		table_->attach(*hscrollbar_, 0, 1, 3, 4, Gtk::FILL|Gtk::EXPAND, Gtk::FILL|Gtk::SHRINK);
+		table_->attach(*vscrollbar_, 1, 2, 0, 3, Gtk::FILL|Gtk::SHRINK, Gtk::FILL|Gtk::EXPAND);
 		add(*table_);
 
 		//add(*last_widget_curves_);
