@@ -2,7 +2,7 @@
 /*!	\file duckmatic.cpp
 **	\brief Template File
 **
-**	$Id: duckmatic.cpp 2022 2008-04-17 18:02:49Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -399,8 +399,14 @@ Duckmatic::get_duck_list()const
 {
 	DuckList ret;
 	DuckMap::const_iterator iter;
+	for(iter=duck_map.begin();iter!=duck_map.end();++iter) if (iter->second->get_type()&Duck::TYPE_POSITION) ret.push_back(iter->second);
+	for(iter=duck_map.begin();iter!=duck_map.end();++iter) if (iter->second->get_type()&Duck::TYPE_VERTEX  ) ret.push_back(iter->second);
+	for(iter=duck_map.begin();iter!=duck_map.end();++iter) if (iter->second->get_type()&Duck::TYPE_TANGENT ) ret.push_back(iter->second);
 	for(iter=duck_map.begin();iter!=duck_map.end();++iter)
-		ret.push_back(iter->second);
+		if (!(iter->second->get_type()&Duck::TYPE_POSITION) &&
+			!(iter->second->get_type()&Duck::TYPE_VERTEX) &&
+			!(iter->second->get_type()&Duck::TYPE_TANGENT))
+			ret.push_back(iter->second);
 	return ret;
 }
 
@@ -875,21 +881,23 @@ Duckmatic::find_duck(synfig::Point point, synfig::Real radius, Duck::Type type)
 	{
 		const Duck::Handle& duck(iter->second);
 
-		if(duck->get_ignore())
+		if(duck->get_ignore() ||
+		   (duck->get_type() && !(type & duck->get_type())))
 			continue;
+
 		Real dist((duck->get_trans_point()-point).mag_squared());
 
 		if(duck->get_type()&Duck::TYPE_VERTEX)
 			dist*=1.0001;
+		else if(duck->get_type()&Duck::TYPE_TANGENT && duck->get_scalar()>0)
+			dist*=1.00005;
 		else if(duck->get_type()&Duck::TYPE_RADIUS)
 			dist*=0.9999;
 
-		if(dist<=closest && !( duck->get_type() && (!(type & duck->get_type())) ) )
+		if(dist<=closest)
 		{
-			{
-				closest=dist;
-				ret=duck;
-			}
+			closest=dist;
+			ret=duck;
 		}
 	}
 
@@ -1588,13 +1596,13 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 					{
 						if(!param_desc->get_origin().empty())
 						{
-								synfigapp::ValueDesc value_desc_origin(value_desc.get_layer(),param_desc->get_origin());
-								add_to_ducks(value_desc_origin,canvas_view, transform_stack);
-								duck->set_origin(last_duck());
+							synfigapp::ValueDesc value_desc_origin(value_desc.get_layer(),param_desc->get_origin());
+							add_to_ducks(value_desc_origin,canvas_view, transform_stack);
+							duck->set_origin(last_duck());
 /*
-								ValueBase value(synfigapp::ValueDesc(value_desc.get_layer(),param_desc->get_origin()).get_value(get_time()));
-								if(value.same_type_as(synfig::Point()))
-									duck->set_origin(value.get(synfig::Point()));
+							ValueBase value(synfigapp::ValueDesc(value_desc.get_layer(),param_desc->get_origin()).get_value(get_time()));
+							if(value.same_type_as(synfig::Point()))
+								duck->set_origin(value.get(synfig::Point()));
 */
 						}
 					}
@@ -1717,13 +1725,13 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 //					add_duck(duck);
 					if(param_desc)
 					{
-								synfigapp::ValueDesc value_desc_origin(value_desc.get_layer(),param_desc->get_origin());
-								add_to_ducks(value_desc_origin,canvas_view, transform_stack);
-								duck->set_origin(last_duck());
+						synfigapp::ValueDesc value_desc_origin(value_desc.get_layer(),param_desc->get_origin());
+						add_to_ducks(value_desc_origin,canvas_view, transform_stack);
+						duck->set_origin(last_duck());
 /*
-								ValueBase value(synfigapp::ValueDesc(value_desc.get_layer(),param_desc->get_origin()).get_value(get_time()));
-								if(value.same_type_as(synfig::Point()))
-									duck->set_origin(value.get(synfig::Point()));
+						ValueBase value(synfigapp::ValueDesc(value_desc.get_layer(),param_desc->get_origin()).get_value(get_time()));
+						if(value.same_type_as(synfig::Point()))
+							duck->set_origin(value.get(synfig::Point()));
 */
 //						if(!param_desc->get_origin().empty())
 //							duck->set_origin(synfigapp::ValueDesc(value_desc.get_layer(),param_desc->get_origin()).get_value(get_time()).get(synfig::Point()));
@@ -1842,15 +1850,15 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 						first_duck = duck;
 					}
 
-					if(param_desc)
+					if(param_desc && !param_desc->get_origin().empty())
 					{
-								synfigapp::ValueDesc value_desc_origin(value_desc.get_layer(),param_desc->get_origin());
-								add_to_ducks(value_desc_origin,canvas_view, transform_stack);
-								duck->set_origin(last_duck());
+						synfigapp::ValueDesc value_desc_origin(value_desc.get_layer(),param_desc->get_origin());
+						add_to_ducks(value_desc_origin,canvas_view, transform_stack);
+						duck->set_origin(last_duck());
 /*
-								ValueBase value(synfigapp::ValueDesc(value_desc.get_layer(),param_desc->get_origin()).get_value(get_time()));
-								if(value.same_type_as(synfig::Point()))
-									duck->set_origin(value.get(synfig::Point()));
+						ValueBase value(synfigapp::ValueDesc(value_desc.get_layer(),param_desc->get_origin()).get_value(get_time()));
+						if(value.same_type_as(synfig::Point()))
+							duck->set_origin(value.get(synfig::Point()));
 */
 //						if(!param_desc->get_origin().empty())
 //							last_duck()->set_origin(synfigapp::ValueDesc(value_desc.get_layer(),param_desc->get_origin()).get_value(get_time()).get(synfig::Point()));
