@@ -2,7 +2,7 @@
 /*!	\file gtkmm/instance.cpp
 **	\brief writeme
 **
-**	$Id: instance.cpp 2098 2008-10-14 21:00:21Z genete $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -946,6 +946,9 @@ Instance::add_actions_to_menu(Gtk::Menu *menu, const synfigapp::Action::ParamLis
 void
 Instance::process_action(synfig::String name, synfigapp::Action::ParamList param_list)
 {
+	//// debug actions
+	// synfig::info("%s:%d process_action: '%s'", __FILE__, __LINE__, name.c_str());
+
 	assert(synfigapp::Action::book().count(name));
 
 	synfigapp::Action::BookEntry entry(synfigapp::Action::book().find(name)->second);
@@ -979,7 +982,7 @@ Instance::process_action(synfig::String name, synfigapp::Action::ParamList param
 			case synfigapp::Action::Param::TYPE_STRING:
 			{
 				String str;
-				if(!studio::App::dialog_entry(entry.local_name, iter->get_local_name()+":"+iter->get_desc(),str))
+				if(!studio::App::dialog_entry(entry.local_name, iter->get_local_name()+": "+iter->get_desc(),str))
 					return;
 				action->set_param(iter->get_name(),str);
 				break;
@@ -1015,6 +1018,7 @@ Instance::make_param_menu(Gtk::Menu *menu,synfig::Canvas::Handle canvas, synfiga
 	param_list=canvas_interface->generate_param_list(value_desc);
 	param_list.add("origin",location);
 
+#ifdef BLINEPOINT_MENU_IS_VERTEX_MENU
 	if(value_desc.get_value_type()==ValueBase::TYPE_BLINEPOINT && value_desc.is_value_node() && ValueNode_Composite::Handle::cast_dynamic(value_desc.get_value_node()))
 	{
 		param_list2=canvas_interface->generate_param_list(
@@ -1025,6 +1029,7 @@ Instance::make_param_menu(Gtk::Menu *menu,synfig::Canvas::Handle canvas, synfiga
 		);
 		param_list2.add("origin",location);
 	}
+#endif	// BLINEPOINT_MENU_IS_VERTEX_MENU
 
 	// Populate the convert menu by looping through
 	// the ValueNode book and find the ones that are
@@ -1171,13 +1176,13 @@ edit_several_waypoints(etl::handle<CanvasView> canvas_view, std::list<synfigapp:
 
 			if(!value_desc.is_value_node())
 			{
-				action=synfigapp::Action::create("value_desc_connect");
+				action=synfigapp::Action::create("ValueDescConnect");
 				action->set_param("dest",value_desc);
 				action->set_param("src",ValueNode::Handle(value_node));
 			}
 			else
 			{
-				action=synfigapp::Action::create("value_node_replace");
+				action=synfigapp::Action::create("ValueNodeReplace");
 				action->set_param("dest",value_desc.get_value_node());
 				action->set_param("src",ValueNode::Handle(value_node));
 			}
@@ -1200,11 +1205,11 @@ edit_several_waypoints(etl::handle<CanvasView> canvas_view, std::list<synfigapp:
 
 		if(value_node)
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("waypoint_set_smart"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("WaypointSetSmart"));
 
 			if(!action)
 			{
-				canvas_view->get_ui_interface()->error(_("Unable to find waypoint_set_smart action"));
+				canvas_view->get_ui_interface()->error(_("Unable to find WaypointSetSmart action"));
 				group.cancel();
 				return;
 			}
