@@ -2,7 +2,7 @@
 /*!	\file keyframeactionmanager.cpp
 **	\brief Template File
 **
-**	$Id: keyframeactionmanager.cpp 1744 2008-02-18 00:29:47Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -59,7 +59,7 @@ static const guint no_prev_popup((guint)-1);
 /* === M E T H O D S ======================================================= */
 
 KeyframeActionManager::KeyframeActionManager():
-	action_group_(Gtk::ActionGroup::create()),
+	action_group_(Gtk::ActionGroup::create("action_group_keyframe_action_manager")),
 	popup_id_(no_prev_popup),
 	queued(false)
 {
@@ -123,7 +123,7 @@ KeyframeActionManager::clear()
 			while(!action_group_->get_actions().empty())action_group_->remove(*action_group_->get_actions().begin());
 #else
 			get_ui_manager()->remove_action_group(action_group_);
-			action_group_=Gtk::ActionGroup::create();
+			action_group_=Gtk::ActionGroup::create("action_group_keyframe_action_manager");
 #endif
 		}
 	}
@@ -155,7 +155,7 @@ KeyframeActionManager::on_keyframe_properties()
 void
 KeyframeActionManager::on_add_keyframe()
 {
-	synfigapp::Action::Handle action(synfigapp::Action::create("keyframe_add"));
+	synfigapp::Action::Handle action(synfigapp::Action::create("KeyframeAdd"));
 
 	if(!action)
 		return;
@@ -210,13 +210,13 @@ KeyframeActionManager::refresh()
 			synfigapp::Action::CATEGORY_KEYFRAME
 		);
 	}
-	if(action_group_->get_action("action-keyframe_add"))
+	if(action_group_->get_action("action-KeyframeAdd"))
 	{
-		action_group_->remove(action_group_->get_action("action-keyframe_add"));
+		action_group_->remove(action_group_->get_action("action-KeyframeAdd"));
 	}
 
 		action_group_->add(Gtk::Action::create(
-			"action-keyframe_add",
+			"action-KeyframeAdd",
 			Gtk::StockID("gtk-add"),
 			_("Add New Keyframe"),_("Add New Keyframe")
 		),
@@ -226,9 +226,9 @@ KeyframeActionManager::refresh()
 	try
 	{
 		canvas_interface_->get_canvas()->keyframe_list().find(canvas_interface_->get_time());
-		action_group_->get_action("action-keyframe_add")->set_sensitive(false);
-		if(action_group_->get_action("action-keyframe_duplicate"))
-			action_group_->get_action("action-keyframe_duplicate")->set_sensitive(false);
+		action_group_->get_action("action-KeyframeAdd")->set_sensitive(false);
+		if(action_group_->get_action("action-KeyframeDuplicate"))
+			action_group_->get_action("action-KeyframeDuplicate")->set_sensitive(false);
 	}
 	catch(...)
 	{
