@@ -2,7 +2,7 @@
 /*!	\file keyframetreestore.cpp
 **	\brief Template File
 **
-**	$Id: keyframetreestore.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -379,7 +379,7 @@ KeyframeTreeStore::set_value_impl(const Gtk::TreeModel::iterator& row, int colum
 
 			{
 				Keyframe keyframe((*row)[model.keyframe]);
-				synfigapp::Action::Handle action(synfigapp::Action::create("keyframe_set_delta"));
+				synfigapp::Action::Handle action(synfigapp::Action::create("KeyframeSetDelta"));
 
 				if(!action)return;
 
@@ -407,7 +407,7 @@ KeyframeTreeStore::set_value_impl(const Gtk::TreeModel::iterator& row, int colum
 			keyframe.set_time(x.get());
 			synfig::info("KeyframeTreeStore::set_value_impl():new_time=%s",keyframe.get_time().get_string().c_str());
 
-			synfigapp::Action::Handle action(synfigapp::Action::create("keyframe_set"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("KeyframeSet"));
 
 			if(!action)
 				return;
@@ -426,7 +426,7 @@ KeyframeTreeStore::set_value_impl(const Gtk::TreeModel::iterator& row, int colum
 			synfig::Keyframe keyframe(*iter->iter);
 			keyframe.set_description(x.get());
 
-			synfigapp::Action::Handle action(synfigapp::Action::create("keyframe_set"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("KeyframeSet"));
 
 			if(!action)
 				return;
@@ -448,7 +448,7 @@ KeyframeTreeStore::set_value_impl(const Gtk::TreeModel::iterator& row, int colum
 	}
 	catch(std::exception x)
 	{
-		g_warning(x.what());
+		g_warning("%s", x.what());
 	}
 }
 
@@ -828,7 +828,7 @@ KeyframeTreeStore::add_keyframe(synfig::Keyframe keyframe)
 	}
 	catch(std::exception x)
 	{
-		g_warning(x.what());
+		g_warning("%s", x.what());
 	}
 }
 
@@ -853,7 +853,7 @@ KeyframeTreeStore::remove_keyframe(synfig::Keyframe keyframe)
 	}
 	catch(std::exception x)
 	{
-		g_warning(x.what());
+		g_warning("%s", x.what());
 	}
 }
 
@@ -896,6 +896,6 @@ KeyframeTreeStore::change_keyframe(synfig::Keyframe keyframe)
 	}
 	catch(std::exception x)
 	{
-		g_warning(x.what());
+		g_warning("%s", x.what());
 	}
 }
