@@ -2,7 +2,7 @@
 /*!	\file layeractionmanager.cpp
 **	\brief Template File
 **
-**	$Id: layeractionmanager.cpp 1790 2008-02-20 16:13:39Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -33,6 +33,7 @@
 #include "layeractionmanager.h"
 #include "layertree.h"
 #include <synfig/context.h>
+#include <synfig/layer_pastecanvas.h>
 #include <synfigapp/action_param.h>
 #include "instance.h"
 #include <synfigapp/selectionmanager.h>
@@ -61,9 +62,9 @@ static const guint no_prev_popup((guint)-1);
 /* === M E T H O D S ======================================================= */
 
 LayerActionManager::LayerActionManager():
-	action_group_(Gtk::ActionGroup::create()),
+	action_group_(Gtk::ActionGroup::create("action_group_layer_action_manager")),
 	popup_id_(no_prev_popup),
-	action_group_copy_paste(Gtk::ActionGroup::create()),
+	action_group_copy_paste(Gtk::ActionGroup::create("action_group_copy_paste")),
 	queued(false)
 {
 	action_cut_=Gtk::Action::create(
@@ -188,7 +189,7 @@ LayerActionManager::clear()
 #ifdef ONE_ACTION_GROUP
 #else
 			if(action_group_)get_ui_manager()->remove_action_group(action_group_);
-			action_group_=Gtk::ActionGroup::create();
+			action_group_=Gtk::ActionGroup::create("action_group_layer_action_manager");
 #endif
 		}
 	}
@@ -333,8 +334,8 @@ void
 LayerActionManager::cut()
 {
 	copy();
-	if(action_group_->get_action("action-layer_remove"))
-		action_group_->get_action("action-layer_remove")->activate();
+	if(action_group_->get_action("action-LayerRemove"))
+		action_group_->get_action("action-LayerRemove")->activate();
 }
 
 void
@@ -380,7 +381,7 @@ LayerActionManager::paste()
 	{
 		layer=(*iter)->clone(guid);
 		layer_selection.push_back(layer);
-		synfigapp::Action::Handle 	action(synfigapp::Action::create("layer_add"));
+		synfigapp::Action::Handle 	action(synfigapp::Action::create("LayerAdd"));
 
 		assert(action);
 		if(!action)
@@ -400,12 +401,15 @@ LayerActionManager::paste()
 			return;
 		}
 
+		etl::handle<Layer_PasteCanvas> paste = etl::handle<Layer_PasteCanvas>::cast_dynamic(layer);
+		if (paste) paste->update_renddesc();
+
 		// synfig::info("DEPTH=%d",depth);
 
 		// Action to move the layer (if necessary)
 		if(depth>0)
 		{
-			synfigapp::Action::Handle 	action(synfigapp::Action::create("layer_move"));
+			synfigapp::Action::Handle 	action(synfigapp::Action::create("LayerMove"));
 
 			assert(action);
 			if(!action)
