@@ -2,7 +2,7 @@
 /*!	\file layerparamtreestore.cpp
 **	\brief Template File
 **
-**	$Id: layerparamtreestore.cpp 2015 2008-04-11 15:37:34Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -79,7 +79,7 @@ LayerParamTreeStore::LayerParamTreeStore(etl::loose_handle<synfigapp::CanvasInte
 	CanvasTreeStore			(canvas_interface_),
 	layer_tree				(layer_tree)
 {
-	queued=false;
+	queued=0;
 	// Connect all the signals
 	canvas_interface()->signal_value_node_changed().connect(sigc::mem_fun(*this,&studio::LayerParamTreeStore::on_value_node_changed));
 	canvas_interface()->signal_value_node_renamed().connect(sigc::mem_fun(*this,&studio::LayerParamTreeStore::on_value_node_renamed));
@@ -267,7 +267,7 @@ LayerParamTreeStore::set_value_impl(const Gtk::TreeModel::iterator& iter, int co
 			g_value_init(x.gobj(),model.active.type());
 			g_value_copy(value.gobj(),x.gobj());
 
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_activate"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerActivate"));
 
 			if(!action)
 				return;
@@ -286,7 +286,7 @@ LayerParamTreeStore::set_value_impl(const Gtk::TreeModel::iterator& iter, int co
 	}
 	catch(std::exception x)
 	{
-		g_warning(x.what());
+		g_warning("%s", x.what());
 	}
 }
 
@@ -303,7 +303,7 @@ void
 LayerParamTreeStore::rebuild()
 {
 	// Profiler profiler("LayerParamTreeStore::rebuild()");
-	if(queued)queued=false;
+	if(queued)queued=0;
 	clear();
 	layer_list=layer_tree->get_selected_layers();
 
@@ -474,7 +474,7 @@ LayerParamTreeStore::queue_rebuild()
 void
 LayerParamTreeStore::refresh()
 {
-	if(queued)queued=false;
+	if(queued)queued=0;
 
 	Gtk::TreeModel::Children children_(children());
 
