@@ -2,7 +2,7 @@
 /*!	\file layertreestore.h
 **	\brief Template Header
 **
-**	$Id: layertreestore.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -103,6 +103,12 @@ public:
 
 private:
 
+	bool queued;
+
+	sigc::connection queue_connection;
+
+	std::map<synfig::Layer::Handle, sigc::connection> subcanvas_changed_connections;
+
 	etl::loose_handle<synfigapp::CanvasInterface> canvas_interface_;
 
 	Glib::RefPtr<Gdk::Pixbuf> layer_icon;
@@ -184,6 +190,8 @@ public:
 
 	bool find_prev_layer_row(const synfig::Layer::Handle &handle, Gtk::TreeModel::Children::iterator &iter);
 
+	void queue_rebuild();
+
 	void rebuild();
 
 	void refresh();
