@@ -2,7 +2,7 @@
 /*!	\file gtkmm/render.cpp
 **	\brief Template File
 **
-**	$Id: render.cpp 1654 2008-02-10 15:41:04Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -40,6 +40,8 @@
 
 #include "general.h"
 
+#include <fstream>
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -287,6 +289,14 @@ RenderSettings::on_render_pressed()
 		canvas_interface_->get_ui_interface()->error(_("Unable to create target for ")+filename);
 		return;
 	}
+	// This is the only way I've found to avoid send a non writable
+	// filename path to the renderer.
+	fstream filetest (filename.c_str(), fstream::out);
+	if (filetest.fail())
+	{
+		canvas_interface_->get_ui_interface()->error(_("Unable to create file for ")+filename);
+		return;
+	}
 
 	hide();
 
