@@ -2,7 +2,7 @@
 /*!	\file state_bline.cpp
 **	\brief Template File
 **
-**	$Id: state_bline.cpp 2014 2008-04-11 14:01:00Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -374,7 +374,7 @@ StateBLine_Context::StateBLine_Context(CanvasView* canvas_view):
 	load_settings();
 
 	// Set up the tool options dialog
-	options_table.attach(*manage(new Gtk::Label(_("BLine Tool"))),	0, 2, 0, 1, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(*manage(new Gtk::Label(_("BLine Tool"))),	0, 2,  0,  1, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 	options_table.attach(entry_id,									0, 2,  1,  2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 	options_table.attach(checkbutton_layer_outline,					0, 2,  2,  3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 	options_table.attach(checkbutton_layer_region,					0, 2,  3,  4, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
@@ -621,13 +621,17 @@ StateBLine_Context::run_()
 			synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
 			Layer::Handle layer(get_canvas_interface()->add_layer_to("curve_gradient",canvas,depth));
-			assert(layer);
+			if (!layer)
+			{
+				group.cancel();
+				throw String(_("Unable to create layer"));
+			}
 			layer_selection.push_back(layer);
 			layer->set_description(get_id()+_(" Gradient"));
 			get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
 
 			{
-				synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+				synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 				assert(action);
 
 				action->set_param("canvas",get_canvas());
@@ -650,7 +654,7 @@ StateBLine_Context::run_()
 			// only link the curve gradient's origin parameter if the option is selected and we're creating more than one layer
 			if (get_layer_link_origins_flag() && layers_to_create > 1)
 			{
-				synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+				synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 				assert(action);
 
 				action->set_param("canvas",get_canvas());
@@ -680,13 +684,17 @@ StateBLine_Context::run_()
 			synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
 			Layer::Handle layer(get_canvas_interface()->add_layer_to("plant",canvas,depth));
-			assert(layer);
+			if (!layer)
+			{
+				group.cancel();
+				throw String(_("Unable to create layer"));
+			}
 			layer_selection.push_back(layer);
 			layer->set_description(get_id()+_(" Plant"));
 			get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
 
 			{
-				synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+				synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 				assert(action);
 
 				action->set_param("canvas",get_canvas());
@@ -709,7 +717,7 @@ StateBLine_Context::run_()
 			// only link the plant's origin parameter if the option is selected and we're creating more than one layer
 			if (get_layer_link_origins_flag() && layers_to_create > 1)
 			{
-				synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+				synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 				assert(action);
 
 				action->set_param("canvas",get_canvas());
@@ -739,7 +747,11 @@ StateBLine_Context::run_()
 			synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
 			Layer::Handle layer(get_canvas_interface()->add_layer_to("region",canvas,depth));
-			assert(layer);
+			if (!layer)
+			{
+				group.cancel();
+				throw String(_("Unable to create layer"));
+			}
 			layer_selection.push_back(layer);
 			layer->set_description(get_id()+_(" Region"));
 			get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
@@ -750,13 +762,10 @@ StateBLine_Context::run_()
 				get_canvas_interface()->signal_layer_param_changed()(layer,"feather");
 			}
 
-			if(get_layer_outline_flag())
-				layer->set_param("color",synfigapp::Main::get_background_color());
-
-			// I don't know if it's safe to reuse the same layer_param_connect action, so I'm
+			// I don't know if it's safe to reuse the same LayerParamConnect action, so I'm
 			// using 2 separate ones.
 			{
-				synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+				synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 				assert(action);
 
 				action->set_param("canvas",get_canvas());
@@ -779,7 +788,7 @@ StateBLine_Context::run_()
 			// only link the region's origin parameter if the option is selected and we're creating more than one layer
 			if (get_layer_link_origins_flag() && layers_to_create > 1)
 			{
-				synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+				synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 				assert(action);
 
 				action->set_param("canvas",get_canvas());
@@ -809,7 +818,11 @@ StateBLine_Context::run_()
 			synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
 			Layer::Handle layer(get_canvas_interface()->add_layer_to("outline",canvas,depth));
-			assert(layer);
+			if (!layer)
+			{
+				group.cancel();
+				throw String(_("Unable to create layer"));
+			}
 			layer_selection.push_back(layer);
 			layer->set_description(get_id()+_(" Outline"));
 			get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
@@ -820,7 +833,7 @@ StateBLine_Context::run_()
 			}
 
 			{
-				synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+				synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 				assert(action);
 
 				action->set_param("canvas",get_canvas());
@@ -843,7 +856,7 @@ StateBLine_Context::run_()
 			// only link the outline's origin parameter if the option is selected and we're creating more than one layer
 			if (get_layer_link_origins_flag() && layers_to_create > 1)
 			{
-				synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+				synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 				assert(action);
 
 				action->set_param("canvas",get_canvas());
@@ -967,10 +980,6 @@ StateBLine_Context::event_mouse_click_handler(const Smach::event& x)
 			return Smach::RESULT_ACCEPT;
 		}
 
-	case BUTTON_RIGHT: // Intercept the right-button click to short-circuit the pop-up menu
-		if (!getenv("SYNFIG_ENABLE_POPUP_MENU_IN_ALL_TOOLS"))
-			return Smach::RESULT_ACCEPT;
-
 	default:
 		return Smach::RESULT_OK;
 	}
