@@ -2,7 +2,7 @@
 /*!	\file state_circle.cpp
 **	\brief Template File
 **
-**	$Id: state_circle.cpp 2110 2008-10-20 23:08:50Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -122,14 +122,15 @@ class studio::StateCircle_Context : public sigc::trackable
 	Gtk::CheckButton checkbutton_layer_curve_gradient;
 	Gtk::CheckButton checkbutton_layer_plant;
 	Gtk::CheckButton checkbutton_layer_link_origins;
+	Gtk::CheckButton checkbutton_layer_origins_at_center;
 
 public:
 
-	// this only counts the layers which use blines - they're the only
-	// ones we link the origins for
+	// this only counts the layers which will have their origins linked
 	int layers_to_create()const
 	{
 		return
+			(get_layer_circle_flag() && get_layer_origins_at_center_flag()) +
 			get_layer_region_flag() +
 			get_layer_outline_flag() +
 			get_layer_curve_gradient_flag() +
@@ -177,6 +178,9 @@ public:
 	bool get_layer_link_origins_flag()const { return checkbutton_layer_link_origins.get_active(); }
 	void set_layer_link_origins_flag(bool x) { return checkbutton_layer_link_origins.set_active(x); }
 
+	bool get_layer_origins_at_center_flag()const { return checkbutton_layer_origins_at_center.get_active(); }
+	void set_layer_origins_at_center_flag(bool x) { return checkbutton_layer_origins_at_center.set_active(x); }
+
 	void refresh_tool_options(); //to refresh the toolbox
 
 	//events
@@ -303,6 +307,11 @@ StateCircle_Context::load_settings()
 		set_layer_link_origins_flag(false);
 	else
 		set_layer_link_origins_flag(true);
+
+	if(settings.get_value("circle.layer_origins_at_center",value) && value=="0")
+		set_layer_origins_at_center_flag(false);
+	else
+		set_layer_origins_at_center_flag(true);
 }
 
 void
@@ -323,6 +332,7 @@ StateCircle_Context::save_settings()
 	settings.set_value("circle.layer_curve_gradient",get_layer_curve_gradient_flag()?"1":"0");
 	settings.set_value("circle.layer_plant",get_layer_plant_flag()?"1":"0");
 	settings.set_value("circle.layer_link_origins",get_layer_link_origins_flag()?"1":"0");
+	settings.set_value("circle.layer_origins_at_center",get_layer_origins_at_center_flag()?"1":"0");
 }
 
 void
@@ -395,13 +405,12 @@ StateCircle_Context::StateCircle_Context(CanvasView* canvas_view):
 	checkbutton_layer_outline(_("Create Outline BLine")),
 	checkbutton_layer_curve_gradient(_("Create Curve Gradient BLine")),
 	checkbutton_layer_plant(_("Create Plant BLine")),
-	checkbutton_layer_link_origins(_("Link BLine Origins"))
+	checkbutton_layer_link_origins(_("Link Origins")),
+	checkbutton_layer_origins_at_center(_("BLine Origins at Center"))
 {
 	egress_on_selection_change=true;
-	// Set up the tool options dialog
-	options_table.attach(*manage(new Gtk::Label(_("Circle Tool"))),	0, 2, 0, 1, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(entry_id,									0, 2, 1, 2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 
+	// Set up the tool options dialog
 	enum_falloff.set_param_desc(ParamDesc("falloff")
 		.set_local_name(_("Falloff"))
 		.set_description(_("Determines the falloff function for the feather"))
@@ -420,24 +429,36 @@ StateCircle_Context::StateCircle_Context(CanvasView* canvas_view):
 
 	load_settings();
 
+	options_table.attach(*manage(new Gtk::Label(_("Circle Tool"))),		0, 2,  0,  1, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(entry_id,										0, 2,  1,  2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+
+   	options_table.attach(checkbutton_layer_circle, 	   	   	   	   	   	0, 2,  2,  3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+   	options_table.attach(checkbutton_layer_outline,	   	   	   	   	   	0, 2,  3,  4, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_region,						0, 2,  4,  5, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_plant,						0, 2,  5,  6, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_curve_gradient,				0, 2,  6,  7, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_link_origins,				0, 2,  7,  8, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_origins_at_center,			0, 2,  8,  9, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+
+	//invert flag
+	options_table.attach(checkbutton_invert,					    	0, 2,  9, 10, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+
+	options_table.attach(*manage(new Gtk::Label(_("Falloff:"))),		0, 1, 10, 11, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(enum_falloff,                              	1, 2, 10, 11, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+
 	//feather stuff
-	options_table.attach(*manage(new Gtk::Label(_("Feather:"))), 0, 1, 2, 3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(spin_feather, 1, 2, 2, 3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(enum_falloff, 0, 2, 4, 5, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(*manage(new Gtk::Label(_("Feather:"))),    	0, 1, 11, 12, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+   	options_table.attach(spin_feather, 							    	1, 2, 11, 12, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+
 #ifdef BLEND_METHOD_IN_TOOL_OPTIONS
-	options_table.attach(enum_blend, 0, 2, 5, 6, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(enum_blend,                                	0, 2, 12, 13, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 #endif	// BLEND_METHOD_IN_TOOL_OPTIONS
-	options_table.attach(checkbutton_invert,					0, 2,  6,  7, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_circle,				0, 2,  7,  8, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_outline,				0, 2,  8,  9, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_region,				0, 2,  9, 10, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_plant,				0, 2, 10, 11, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_curve_gradient,		0, 2, 11, 12, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_link_origins,		0, 2, 12, 13, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(*manage(new Gtk::Label(_("BLine Points:"))), 0, 1, 13, 14, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(spin_number_of_bline_points, 1, 2, 13, 14, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(*manage(new Gtk::Label(_("Point Angle Offset:"))), 0, 1, 14, 15, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(spin_bline_point_angle_offset, 1, 2, 14, 15, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+
+	options_table.attach(*manage(new Gtk::Label(_("BLine Points:"))),	0, 1, 13, 14, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(spin_number_of_bline_points,					1, 2, 13, 14, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+
+options_table.attach(*manage(new Gtk::Label(_("Point Angle Offset:"))),	0, 1, 14, 15, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(spin_bline_point_angle_offset,					1, 2, 14, 15, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 
 	options_table.show_all();
 
@@ -554,7 +575,19 @@ StateCircle_Context::make_circle(const Point& _p1, const Point& _p2)
 	Real tangent(4 * ((points == 2)
 					  ? 1
 					  : ((2 * Angle::cos(angle/2).get() - Angle::cos(angle).get() - 1) / Angle::sin(angle).get())));
-	Real x(p1[0]), y(p1[1]);
+	Vector origin;
+	Real x, y;
+
+	if (get_layer_origins_at_center_flag())
+	{
+		x = y = 0;
+		origin = p1;
+	}
+	else
+	{
+		x = p1[0];
+		y = p1[1];
+	}
 
 	std::vector<BLinePoint> new_list;
 	for (int i = 0; i < points; i++)
@@ -570,7 +603,7 @@ StateCircle_Context::make_circle(const Point& _p1, const Point& _p2)
 	ValueNode_BLine::Handle value_node_bline(ValueNode_BLine::create(new_list));
 	assert(value_node_bline);
 
-	ValueNode_Const::Handle value_node_origin(ValueNode_Const::create(Vector()));
+	ValueNode_Const::Handle value_node_origin(ValueNode_Const::create(origin));
 	assert(value_node_origin);
 
 	// Set the looping flag
@@ -592,11 +625,14 @@ StateCircle_Context::make_circle(const Point& _p1, const Point& _p2)
 		get_falloff() >= 0 && get_falloff() < CIRCLE_NUM_FALLOFF)
 	{
 		layer=get_canvas_interface()->add_layer_to("circle",canvas,depth);
+		if (!layer)
+		{
+			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
+			group.cancel();
+			return;
+		}
 		layer_selection.push_back(layer);
 
-		layer->set_param("origin",p1);
-		get_canvas_interface()->signal_layer_param_changed()(layer,"origin");
-
 		layer->set_param("radius",(p2-p1).mag());
 		get_canvas_interface()->signal_layer_param_changed()(layer,"radius");
 
@@ -617,10 +653,33 @@ StateCircle_Context::make_circle(const Point& _p1, const Point& _p2)
 		layer->set_description(get_id());
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
 
-		if(get_layer_outline_flag())
+		// only link the circle's origin parameter if the option is selected, we're putting bline
+		// origins at their centers, and we're creating more than one layer
+		if (get_layer_link_origins_flag() && get_layer_origins_at_center_flag() && layers_to_create > 1)
 		{
-			layer->set_param("color",synfigapp::Main::get_background_color());
-			get_canvas_interface()->signal_layer_param_changed()(layer,"color");
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
+			assert(action);
+
+			action->set_param("canvas",get_canvas());
+			action->set_param("canvas_interface",get_canvas_interface());
+			action->set_param("layer",layer);
+			if(!action->set_param("param",String("origin")))
+				synfig::error("LayerParamConnect didn't like \"param\"");
+			if(!action->set_param("value_node",ValueNode::Handle(value_node_origin)))
+				synfig::error("LayerParamConnect didn't like \"value_node\"");
+
+			if(!get_canvas_interface()->get_instance()->perform_action(action))
+			{
+				//get_canvas_view()->get_ui_interface()->error(_("Unable to create Circle layer"));
+				group.cancel();
+				throw String(_("Unable to create Circle layer"));
+				return;
+			}
+		}
+		else
+		{
+			layer->set_param("origin",p1);
+			get_canvas_interface()->signal_layer_param_changed()(layer,"origin");
 		}
 	}
 
@@ -633,7 +692,12 @@ StateCircle_Context::make_circle(const Point& _p1, const Point& _p2)
 		synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
 		Layer::Handle layer(get_canvas_interface()->add_layer_to("curve_gradient",canvas,depth));
-		assert(layer);
+		if (!layer)
+		{
+			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
+			group.cancel();
+			return;
+		}
 		layer_selection.push_back(layer);
 		layer->set_description(get_id()+_(" Gradient"));
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
@@ -644,7 +708,7 @@ StateCircle_Context::make_circle(const Point& _p1, const Point& _p2)
 #endif	// BLEND_METHOD_IN_TOOL_OPTIONS
 
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -667,7 +731,7 @@ StateCircle_Context::make_circle(const Point& _p1, const Point& _p2)
 		// only link the curve gradient's origin parameter if the option is selected and we're creating more than one layer
 		if (get_layer_link_origins_flag() && layers_to_create > 1)
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -686,6 +750,11 @@ StateCircle_Context::make_circle(const Point& _p1, const Point& _p2)
 				return;
 			}
 		}
+		else
+		{
+			layer->set_param("origin",origin);
+			get_canvas_interface()->signal_layer_param_changed()(layer,"origin");
+		}
 	}
 
 	///////////////////////////////////////////////////////////////////////////
@@ -697,7 +766,12 @@ StateCircle_Context::make_circle(const Point& _p1, const Point& _p2)
 		synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
 		Layer::Handle layer(get_canvas_interface()->add_layer_to("plant",canvas,depth));
-		assert(layer);
+		if (!layer)
+		{
+			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
+			group.cancel();
+			return;
+		}
 		layer_selection.push_back(layer);
 		layer->set_description(get_id()+_(" Plant"));
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
@@ -708,7 +782,7 @@ StateCircle_Context::make_circle(const Point& _p1, const Point& _p2)
 #endif	// BLEND_METHOD_IN_TOOL_OPTIONS
 
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -731,7 +805,7 @@ StateCircle_Context::make_circle(const Point& _p1, const Point& _p2)
 		// only link the plant's origin parameter if the option is selected and we're creating more than one layer
 		if (get_layer_link_origins_flag() && layers_to_create > 1)
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -750,6 +824,11 @@ StateCircle_Context::make_circle(const Point& _p1, const Point& _p2)
 				return;
 			}
 		}
+		else
+		{
+			layer->set_param("origin",origin);
+			get_canvas_interface()->signal_layer_param_changed()(layer,"origin");
+		}
 	}
 
 	///////////////////////////////////////////////////////////////////////////
@@ -761,7 +840,12 @@ StateCircle_Context::make_circle(const Point& _p1, const Point& _p2)
 		synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
 		Layer::Handle layer(get_canvas_interface()->add_layer_to("region",canvas,depth));
-		assert(layer);
+		if (!layer)
+		{
+			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
+			group.cancel();
+			return;
+		}
 		layer_selection.push_back(layer);
 		layer->set_description(get_id()+_(" Region"));
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
@@ -777,13 +861,10 @@ StateCircle_Context::make_circle(const Point& _p1, const Point& _p2)
 		layer->set_param("invert",get_invert());
 		get_canvas_interface()->signal_layer_param_changed()(layer,"invert");
 
-		if(get_layer_outline_flag())
-			layer->set_param("color",synfigapp::Main::get_background_color());
-
-		// I don't know if it's safe to reuse the same layer_param_connect action, so I'm
+		// I don't know if it's safe to reuse the same LayerParamConnect action, so I'm
 		// using 2 separate ones.
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -806,7 +887,7 @@ StateCircle_Context::make_circle(const Point& _p1, const Point& _p2)
 		// only link the region's origin parameter if the option is selected and we're creating more than one layer
 		if (get_layer_link_origins_flag() && layers_to_create > 1)
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -825,6 +906,11 @@ StateCircle_Context::make_circle(const Point& _p1, const Point& _p2)
 				return;
 			}
 		}
+		else
+		{
+			layer->set_param("origin",origin);
+			get_canvas_interface()->signal_layer_param_changed()(layer,"origin");
+		}
 	}
 
 	///////////////////////////////////////////////////////////////////////////
@@ -834,7 +920,12 @@ StateCircle_Context::make_circle(const Point& _p1, const Point& _p2)
 	if (get_layer_outline_flag())
 	{
 		Layer::Handle layer(get_canvas_interface()->add_layer_to("outline",canvas,depth));
-		assert(layer);
+		if (!layer)
+		{
+			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
+			group.cancel();
+			return;
+		}
 		layer_selection.push_back(layer);
 		layer->set_description(get_id()+_(" Outline"));
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
@@ -851,7 +942,7 @@ StateCircle_Context::make_circle(const Point& _p1, const Point& _p2)
 		get_canvas_interface()->signal_layer_param_changed()(layer,"invert");
 
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -874,7 +965,7 @@ StateCircle_Context::make_circle(const Point& _p1, const Point& _p2)
 		// only link the outline's origin parameter if the option is selected and we're creating more than one layer
 		if (get_layer_link_origins_flag() && layers_to_create > 1)
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -893,6 +984,11 @@ StateCircle_Context::make_circle(const Point& _p1, const Point& _p2)
 				return;
 			}
 		}
+		else
+		{
+			layer->set_param("origin",origin);
+			get_canvas_interface()->signal_layer_param_changed()(layer,"origin");
+		}
 	}
 
 	egress_on_selection_change=false;
