@@ -2,7 +2,7 @@
 /*!	\file state_draw.cpp
 **	\brief Template File
 **
-**	$Id: state_draw.cpp 2014 2008-04-11 14:01:00Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -115,7 +115,7 @@ class studio::StateDraw_Context : public sigc::trackable
 	Duckmatic::Type old_duckmask;
 
 	void fill_last_stroke();
-	void fill_last_stroke_and_unselect_other_layers();
+	Smach::event_result fill_last_stroke_and_unselect_other_layers();
 
 	Smach::event_result new_bline(std::list<synfig::BLinePoint> bline,bool loop_bline_flag,float radius);
 
@@ -589,10 +589,6 @@ StateDraw_Context::event_mouse_down_handler(const Smach::event& x)
 			return Smach::RESULT_ACCEPT;
 		}
 
-	case BUTTON_RIGHT: // Intercept the right-button click to short-circuit the pop-up menu
-		if (!getenv("SYNFIG_ENABLE_POPUP_MENU_IN_ALL_TOOLS"))
-			return Smach::RESULT_ACCEPT;
-
 	default:
 		return Smach::RESULT_OK;
 	}
@@ -629,7 +625,7 @@ StateDraw_Context::event_stroke(const Smach::event& x)
 
 	assert(event.stroke_data);
 
-	get_work_area()->add_stroke(event.stroke_data,synfigapp::Main::get_foreground_color());
+	get_work_area()->add_stroke(event.stroke_data,synfigapp::Main::get_outline_color());
 
 	if(nested==0)
 	{
@@ -681,7 +677,7 @@ StateDraw_Context::process_stroke(StrokeData stroke_data, WidthData width_data,
 		}
 	}
 
-	//get_work_area()->add_stroke(event.stroke_data,synfigapp::Main::get_foreground_color());
+	//get_work_area()->add_stroke(event.stroke_data,synfigapp::Main::get_outline_color());
 	//stroke_list.push_back(event.stroke_data);
 	//refresh_ducks();
 
@@ -1038,7 +1034,15 @@ StateDraw_Context::new_bline(std::list<synfig::BLinePoint> bline,bool loop_bline
 
 		// fill_last_stroke() will take care of clearing the selection if we're calling it
 		if(get_outline_flag() && get_region_flag())
-			fill_last_stroke_and_unselect_other_layers();
+		{
+			if (fill_last_stroke_and_unselect_other_layers() == Smach::RESULT_ERROR)
+			{
+				get_canvas_view()->get_selection_manager()->set_selected_layers(layer_list);
+				get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
+				group.cancel();
+				return Smach::RESULT_ERROR;
+			}
+		}
 		else
 			get_canvas_interface()->get_selection_manager()->clear_selected_layers();
 
@@ -1050,11 +1054,25 @@ StateDraw_Context::new_bline(std::list<synfig::BLinePoint> bline,bool loop_bline
 		if(get_outline_flag())
 		{
 			layer=get_canvas_interface()->add_layer_to("outline",canvas,depth);
+			if (!layer)
+			{
+				get_canvas_view()->get_selection_manager()->set_selected_layers(layer_list);
+				get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
+				group.cancel();
+				return Smach::RESULT_ERROR;
+			}
 			layer->set_description(get_id()+_(" Outline"));
 		}
 		else
 		{
 			layer=get_canvas_interface()->add_layer_to("region",canvas,depth);
+			if (!layer)
+			{
+				get_canvas_view()->get_selection_manager()->set_selected_layers(layer_list);
+				get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
+				group.cancel();
+				return Smach::RESULT_ERROR;
+			}
 			layer->set_description(get_id()+_(" Region"));
 		}
 
@@ -1071,7 +1089,7 @@ StateDraw_Context::new_bline(std::list<synfig::BLinePoint> bline,bool loop_bline
 			get_canvas_interface()->
 			  change_value(synfigapp::ValueDesc(layer,"origin"),shift_origin_vector);
 
-		synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+		synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 
 		assert(action);
 
@@ -1273,7 +1291,7 @@ StateDraw_Context::new_region(std::list<synfig::BLinePoint> bline, synfig::Real
 
 	std::list<synfigapp::ValueDesc> vertex_list;
 
-	printf("new_region with %d bline points\n", bline.size());
+	printf("new_region with %zd bline points\n", bline.size());
 
 	// First we need to come up with a rough list of
 	// BLinePoints that we are going to be using to
@@ -1316,7 +1334,7 @@ StateDraw_Context::new_region(std::list<synfig::BLinePoint> bline, synfig::Real
 
 	assert(vertex_list.back().is_valid());
 
-	printf("vertex list with %d bline points\n", vertex_list.size());
+	printf("vertex list with %zd bline points\n", vertex_list.size());
 
 	// Remove any duplicates
 	{
@@ -1537,7 +1555,7 @@ StateDraw_Context::new_region(std::list<synfig::BLinePoint> bline, synfig::Real
 				// synfig::info(__FILE__":%d: value_prev 0x%08X:%d",__LINE__,value_prev.get_parent_value_node().get(),value_prev.get_index());
 				// synfig::info(__FILE__":%d: value_desc 0x%08X:%d",__LINE__,value_desc.get_parent_value_node().get(),value_desc.get_index());
 				// synfig::info(__FILE__":%d: value_next 0x%08X:%d",__LINE__,value_next.get_parent_value_node().get(),value_next.get_index());
-						
+
 				/*
 				  if(value_prev.parent_is_value_node() && value_desc.parent_is_value_node() && value_next.parent_is_value_node())
 				  {
@@ -1587,7 +1605,7 @@ StateDraw_Context::new_region(std::list<synfig::BLinePoint> bline, synfig::Real
 						// 		   (*(value_desc.get_parent_value_node()))(get_time()).get_loop()
 						// 		   // value_desc.get_value_node().get_loop(),
 						// 		);
-						// 
+						//
 						// 	// Fill in missing vertices
 						// 	// \todo take loops into account: seeing (15, 2, 3, 4) probably means that (0, 1) is missing, not 14 through 3
 						// 	if(value_desc.get_index()<value_next.get_index()-1)
@@ -1774,8 +1792,13 @@ StateDraw_Context::new_region(std::list<synfig::BLinePoint> bline, synfig::Real
 		synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
 		layer=get_canvas_interface()->add_layer_to("region",canvas,depth);
-		assert(layer);
-		layer->set_param("color",synfigapp::Main::get_background_color());
+		if (!layer)
+		{
+			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
+			group.cancel();
+			return Smach::RESULT_ERROR;
+		}
+
 		if(get_feather())
 		{
 			layer->set_param("feather",get_feather());
@@ -1783,7 +1806,7 @@ StateDraw_Context::new_region(std::list<synfig::BLinePoint> bline, synfig::Real
 		}
 		get_canvas_interface()->signal_layer_param_changed()(layer,"color");
 
-		synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+		synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 
 		assert(action);
 
@@ -1835,7 +1858,7 @@ StateDraw_Context::extend_bline_from_begin(ValueNode_BLine::Handle value_node,st
 
 	if (complete_loop)
 	{
-		synfigapp::Action::Handle action(synfigapp::Action::create("value_node_dynamic_list_loop"));
+		synfigapp::Action::Handle action(synfigapp::Action::create("ValueNodeDynamicListLoop"));
 		assert(action);
 
 		action->set_param("canvas",get_canvas());
@@ -1855,7 +1878,7 @@ StateDraw_Context::extend_bline_from_begin(ValueNode_BLine::Handle value_node,st
 	{
 		ValueNode_Composite::Handle composite(ValueNode_Composite::create(*iter));
 
-		synfigapp::Action::Handle action(synfigapp::Action::create("value_node_dynamic_list_insert"));
+		synfigapp::Action::Handle action(synfigapp::Action::create("ValueNodeDynamicListInsert"));
 
 		assert(action);
 		synfigapp::ValueDesc value_desc(value_node,0);
@@ -1886,7 +1909,7 @@ StateDraw_Context::extend_bline_from_end(ValueNode_BLine::Handle value_node,std:
 
 	if (complete_loop)
 	{
-		synfigapp::Action::Handle action(synfigapp::Action::create("value_node_dynamic_list_loop"));
+		synfigapp::Action::Handle action(synfigapp::Action::create("ValueNodeDynamicListLoop"));
 		assert(action);
 
 		action->set_param("canvas",get_canvas());
@@ -1906,7 +1929,7 @@ StateDraw_Context::extend_bline_from_end(ValueNode_BLine::Handle value_node,std:
 	{
 		ValueNode_Composite::Handle composite(ValueNode_Composite::create(*iter));
 
-		synfigapp::Action::Handle action(synfigapp::Action::create("value_node_dynamic_list_insert"));
+		synfigapp::Action::Handle action(synfigapp::Action::create("ValueNodeDynamicListInsert"));
 
 		assert(action);
 		synfigapp::ValueDesc value_desc(value_node,value_node->link_count());
@@ -1946,11 +1969,11 @@ StateDraw_Context::reverse_bline(std::list<synfig::BLinePoint> &bline)
 	}
 }
 
-void
+Smach::event_result
 StateDraw_Context::fill_last_stroke_and_unselect_other_layers()
 {
 	if(!last_stroke)
-		return;
+		return Smach::RESULT_OK;
 
 	synfigapp::Action::PassiveGrouper group(get_canvas_interface()->get_instance().get(),_("Fill Stroke"));
 
@@ -1972,11 +1995,10 @@ StateDraw_Context::fill_last_stroke_and_unselect_other_layers()
 
 	get_canvas_interface()->get_selection_manager()->clear_selected_layers();
 	layer=get_canvas_interface()->add_layer_to("region", canvas, depth);
-	assert(layer);
-	layer->set_param("color",synfigapp::Main::get_background_color());
+	if (!layer) return Smach::RESULT_ERROR;
 	layer->set_description(last_stroke_id + _(" Region"));
 
-	synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+	synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 
 	assert(action);
 
@@ -1992,9 +2014,10 @@ StateDraw_Context::fill_last_stroke_and_unselect_other_layers()
 	{
 		get_canvas_view()->get_ui_interface()->error(_("Unable to create Region layer"));
 		group.cancel();
-		return;
+		return Smach::RESULT_OK;
 	}
 	get_canvas_view()->get_selection_manager()->set_selected_layer(layer);
+	return Smach::RESULT_OK;
 }
 
 void
