@@ -2,7 +2,7 @@
 /*!	\file state_eyedrop.cpp
 **	\brief Template File
 **
-**	$Id: state_eyedrop.cpp 1143 2007-11-13 09:13:07Z pabs $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -135,7 +135,7 @@ StateEyedrop_Context::event_workarea_mouse_button_down_handler(const Smach::even
 	if(event.button==BUTTON_LEFT)
 	{
 		Color color(canvas_view->get_canvas()->get_context().get_color(event.pos));
-		synfigapp::Main::set_foreground_color(color);
+		synfigapp::Main::set_outline_color(color);
 		studio::App::dialog_color->set_color(color);
 		return Smach::RESULT_ACCEPT;
 	}
