@@ -2,7 +2,7 @@
 /*!	\file state_normal.cpp
 **	\brief Template File
 **
-**	$Id: state_normal.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -297,13 +297,13 @@ StateNormal_Context::edit_several_waypoints(std::list<synfigapp::ValueDesc> valu
 
 			if(!value_desc.is_value_node())
 			{
-				action=synfigapp::Action::create("value_desc_connect");
+				action=synfigapp::Action::create("ValueDescConnect");
 				action->set_param("dest",value_desc);
 				action->set_param("src",ValueNode::Handle(value_node));
 			}
 			else
 			{
-				action=synfigapp::Action::create("value_node_replace");
+				action=synfigapp::Action::create("ValueNodeReplace");
 				action->set_param("dest",value_desc.get_value_node());
 				action->set_param("src",ValueNode::Handle(value_node));
 			}
@@ -329,11 +329,11 @@ StateNormal_Context::edit_several_waypoints(std::list<synfigapp::ValueDesc> valu
 		if(value_node)
 		{
 
-			synfigapp::Action::Handle action(synfigapp::Action::create("waypoint_set_smart"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("WaypointSetSmart"));
 
 			if(!action)
 			{
-				get_canvas_view()->get_ui_interface()->error(_("Unable to find waypoint_set_smart action"));
+				get_canvas_view()->get_ui_interface()->error(_("Unable to find WaypointSetSmart action"));
 				group.cancel();
 				return;
 			}
