@@ -2,7 +2,7 @@
 /*!	\file state_rectangle.cpp
 **	\brief Template File
 **
-**	$Id: state_rectangle.cpp 2098 2008-10-14 21:00:21Z genete $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -352,23 +352,23 @@ StateRectangle_Context::StateRectangle_Context(CanvasView* canvas_view):
 	options_table.attach(*manage(new Gtk::Label(_("Rectangle Tool"))),	0, 2,  0,  1, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 	options_table.attach(entry_id,										0, 2,  1,  2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 
-	//expand stuff
-	options_table.attach(*manage(new Gtk::Label(_("Expansion:"))),		0, 1,  2,  3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(spin_expand,									1, 2,  2,  3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-
-	//feather stuff
-	options_table.attach(*manage(new Gtk::Label(_("Feather:"))),		0, 1,  3,  4, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(spin_feather,									1, 2,  3,  4, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_rectangle,					0, 2,  2,  3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_outline,						0, 2,  3,  4, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_region,						0, 2,  4,  5, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_plant,						0, 2,  5,  6, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_curve_gradient,				0, 2,  6,  7, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_link_origins,				0, 2,  7,  8, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 
 	//invert flag
-	options_table.attach(checkbutton_invert,							1, 2,  4 , 5, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+   	options_table.attach(checkbutton_invert,   	   	   	   	   	   	   	0, 2,  8,  9, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 
-	options_table.attach(checkbutton_layer_rectangle,					0, 2,  7,  8, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_outline,						0, 2,  8,  9, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_region,						0, 2,  9, 10, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_plant,						0, 2, 10, 11, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_curve_gradient,				0, 2, 11, 12, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_link_origins,				0, 2, 12, 13, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	//expand stuff
+   	options_table.attach(*manage(new Gtk::Label(_("Expansion:"))), 	   	0, 1,  9, 10, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(spin_expand,									1, 2,  9, 10, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+
+ 	//feather stuff
+	options_table.attach(*manage(new Gtk::Label(_("Feather:"))),		0, 1, 10, 11, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(spin_feather,									1, 2, 10, 11, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 
 	options_table.show_all();
 
@@ -490,8 +490,8 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 	{
 		new_list.push_back(*(new BLinePoint));
 		new_list[i].set_width(1);
-		new_list[i].set_vertex(Point((i==0||i==1)?x_min:x_max,
-									 (i==0||i==3)?y_min:y_max));
+		new_list[i].set_vertex(Point((i==0||i==3)?x_min:x_max,
+									 (i==0||i==1)?y_min:y_max));
 		new_list[i].set_tangent(Point(0,0));
 	}
 
@@ -519,6 +519,12 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 	if (get_layer_rectangle_flag())
 	{
 		layer=get_canvas_interface()->add_layer_to("rectangle",canvas,depth);
+		if (!layer)
+		{
+			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
+			group.cancel();
+			return;
+		}
 		layer_selection.push_back(layer);
 
 		layer->set_param("point1",p1);
@@ -535,12 +541,6 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 
 		layer->set_description(get_id());
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
-
-		if(get_layer_outline_flag())
-		{
-			layer->set_param("color",synfigapp::Main::get_background_color());
-			get_canvas_interface()->signal_layer_param_changed()(layer,"color");
-		}
 	}
 
 	///////////////////////////////////////////////////////////////////////////
@@ -552,13 +552,18 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 		synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
 		Layer::Handle layer(get_canvas_interface()->add_layer_to("curve_gradient",canvas,depth));
-		assert(layer);
+		if (!layer)
+		{
+			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
+			group.cancel();
+			return;
+		}
 		layer_selection.push_back(layer);
 		layer->set_description(get_id()+_(" Gradient"));
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
 
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -581,7 +586,7 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 		// only link the curve gradient's origin parameter if the option is selected and we're creating more than one layer
 		if (get_layer_link_origins_flag() && layers_to_create > 1)
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -611,13 +616,18 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 		synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
 		Layer::Handle layer(get_canvas_interface()->add_layer_to("plant",canvas,depth));
-		assert(layer);
+		if (!layer)
+		{
+			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
+			group.cancel();
+			return;
+		}
 		layer_selection.push_back(layer);
 		layer->set_description(get_id()+_(" Plant"));
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
 
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -640,7 +650,7 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 		// only link the plant's origin parameter if the option is selected and we're creating more than one layer
 		if (get_layer_link_origins_flag() && layers_to_create > 1)
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -670,7 +680,12 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 		synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
 		Layer::Handle layer(get_canvas_interface()->add_layer_to("region",canvas,depth));
-		assert(layer);
+		if (!layer)
+		{
+			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
+			group.cancel();
+			return;
+		}
 		layer_selection.push_back(layer);
 		layer->set_description(get_id()+_(" Region"));
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
@@ -681,13 +696,10 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 		layer->set_param("invert",get_invert());
 		get_canvas_interface()->signal_layer_param_changed()(layer,"invert");
 
-		if(get_layer_outline_flag())
-			layer->set_param("color",synfigapp::Main::get_background_color());
-
-		// I don't know if it's safe to reuse the same layer_param_connect action, so I'm
+		// I don't know if it's safe to reuse the same LayerParamConnect action, so I'm
 		// using 2 separate ones.
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -710,7 +722,7 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 		// only link the region's origin parameter if the option is selected and we're creating more than one layer
 		if (get_layer_link_origins_flag() && layers_to_create > 1)
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -738,7 +750,12 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 	if (get_layer_outline_flag())
 	{
 		Layer::Handle layer(get_canvas_interface()->add_layer_to("outline",canvas,depth));
-		assert(layer);
+		if (!layer)
+		{
+			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
+			group.cancel();
+			return;
+		}
 		layer_selection.push_back(layer);
 		layer->set_description(get_id()+_(" Outline"));
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
@@ -750,7 +767,7 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 		get_canvas_interface()->signal_layer_param_changed()(layer,"invert");
 
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -773,7 +790,7 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 		// only link the outline's origin parameter if the option is selected and we're creating more than one layer
 		if (get_layer_link_origins_flag() && layers_to_create > 1)
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
