@@ -2,7 +2,7 @@
 /*!	\file state_sketch.cpp
 **	\brief Template File
 **
-**	$Id: state_sketch.cpp 1989 2008-04-08 09:59:24Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -230,7 +230,7 @@ StateSketch_Context::toggle_show_sketch()
 }
 
 StateSketch_Context::StateSketch_Context(CanvasView* canvas_view):
-	action_group(Gtk::ActionGroup::create()),
+	action_group(Gtk::ActionGroup::create("action_group_state_sketch")),
 	canvas_view_(canvas_view),
 	is_working(*canvas_view),
 	prev_workarea_layer_status_(get_work_area()->get_allow_layer_clicks()),
@@ -487,10 +487,6 @@ StateSketch_Context::event_mouse_down_handler(const Smach::event& x)
 			return Smach::RESULT_ACCEPT;
 		}
 
-	case BUTTON_RIGHT: // Intercept the right-button click to short-circuit the pop-up menu
-		if (!getenv("SYNFIG_ENABLE_POPUP_MENU_IN_ALL_TOOLS"))
-			return Smach::RESULT_ACCEPT;
-
 	default:
 		return Smach::RESULT_OK;
 	}
@@ -503,7 +499,7 @@ StateSketch_Context::event_stroke(const Smach::event& x)
 
 	assert(event.stroke_data);
 
-	get_work_area()->add_persistent_stroke(event.stroke_data,synfigapp::Main::get_foreground_color());
+	get_work_area()->add_persistent_stroke(event.stroke_data,synfigapp::Main::get_outline_color());
 
 	return Smach::RESULT_ACCEPT;
 }
