@@ -119,14 +119,15 @@ class studio::StateStar_Context : public sigc::trackable
 	Gtk::CheckButton checkbutton_layer_curve_gradient;
 	Gtk::CheckButton checkbutton_layer_plant;
 	Gtk::CheckButton checkbutton_layer_link_origins;
+	Gtk::CheckButton checkbutton_layer_origins_at_center;
 
 public:
 
-	// this only counts the layers which use blines - they're the only
-	// ones we link the origins for
+	// this only counts the layers which will have their origins linked
 	int layers_to_create()const
 	{
 		return
+			(get_layer_star_flag() && get_layer_origins_at_center_flag()) +
 			get_layer_region_flag() +
 			get_layer_outline_flag() +
 			get_layer_curve_gradient_flag() +
@@ -184,6 +185,9 @@ public:
 	bool get_layer_link_origins_flag()const { return checkbutton_layer_link_origins.get_active(); }
 	void set_layer_link_origins_flag(bool x) { return checkbutton_layer_link_origins.set_active(x); }
 
+	bool get_layer_origins_at_center_flag()const { return checkbutton_layer_origins_at_center.get_active(); }
+	void set_layer_origins_at_center_flag(bool x) { return checkbutton_layer_origins_at_center.set_active(x); }
+
 	void refresh_tool_options(); //to refresh the toolbox
 
 	//events
@@ -328,6 +332,11 @@ StateStar_Context::load_settings()
 		set_layer_link_origins_flag(false);
 	else
 		set_layer_link_origins_flag(true);
+
+	if(settings.get_value("star.layer_origins_at_center",value) && value=="0")
+		set_layer_origins_at_center_flag(false);
+	else
+		set_layer_origins_at_center_flag(true);
 }
 
 void
@@ -350,6 +359,7 @@ StateStar_Context::save_settings()
 	settings.set_value("star.layer_curve_gradient",get_layer_curve_gradient_flag()?"1":"0");
 	settings.set_value("star.layer_plant",get_layer_plant_flag()?"1":"0");
 	settings.set_value("star.layer_link_origins",get_layer_link_origins_flag()?"1":"0");
+	settings.set_value("star.layer_origins_at_center",get_layer_origins_at_center_flag()?"1":"0");
 }
 
 void
@@ -433,7 +443,8 @@ StateStar_Context::StateStar_Context(CanvasView* canvas_view):
 	checkbutton_layer_outline(_("Create Outline BLine")),
 	checkbutton_layer_curve_gradient(_("Create Curve Gradient BLine")),
 	checkbutton_layer_plant(_("Create Plant BLine")),
-	checkbutton_layer_link_origins(_("Link BLine Origins"))
+	checkbutton_layer_link_origins(_("Link Origins")),
+	checkbutton_layer_origins_at_center(_("BLine Origins at Center"))
 {
 	egress_on_selection_change=true;
 
@@ -442,30 +453,39 @@ StateStar_Context::StateStar_Context(CanvasView* canvas_view):
 	// Set up the tool options dialog
 	options_table.attach(*manage(new Gtk::Label(_("Star Tool"))),			0, 2,  0,  1, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 	options_table.attach(entry_id,											0, 2,  1,  2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(*manage(new Gtk::Label(_("Feather:"))),			0, 1,  2,  3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(spin_feather,										1, 2,  2,  3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_invert,								0, 2,  5,  6, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_regular_polygon,						0, 2,  6,  7, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_star,							0, 2,  7,  8, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_outline,							0, 2,  8,  9, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_region,							0, 2,  9, 10, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_plant,							0, 2, 10, 11, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_curve_gradient,					0, 2, 11, 12, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_link_origins,					0, 2, 12, 13, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(*manage(new Gtk::Label(_("Number of Points:"))),	0, 1, 13, 14, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(spin_number_of_points,								1, 2, 13, 14, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(*manage(new Gtk::Label(_("Inner Tangent:"))),		0, 1, 14, 15, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(spin_inner_tangent,								1, 2, 14, 15, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(*manage(new Gtk::Label(_("Outer Tangent:"))),		0, 1, 15, 16, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(spin_outer_tangent,								1, 2, 15, 16, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(*manage(new Gtk::Label(_("Inner Width:"))),		0, 1, 16, 17, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(spin_inner_width,									1, 2, 16, 17, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(*manage(new Gtk::Label(_("Outer Width:"))),		0, 1, 17, 18, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(spin_outer_width,									1, 2, 17, 18, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(*manage(new Gtk::Label(_("Radius Ratio:"))),		0, 1, 18, 19, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(spin_radius_ratio,									1, 2, 18, 19, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(*manage(new Gtk::Label(_("Angle Offset:"))),		0, 1, 19, 20, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(spin_angle_offset,									1, 2, 19, 20, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_star,							0, 2,  2,  3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_outline,							0, 2,  3,  4, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_region,							0, 2,  4,  5, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_plant,							0, 2,  5,  6, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_curve_gradient,					0, 2,  6,  7, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_link_origins,					0, 2,  7,  8, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_origins_at_center,				0, 2,  8,  9, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_invert,								0, 2,  9, 10, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_regular_polygon,						0, 2, 10, 11, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+
+	options_table.attach(*manage(new Gtk::Label(_("Feather:"))),			0, 1, 11, 12, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(spin_feather,										1, 2, 11, 12, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+
+	options_table.attach(*manage(new Gtk::Label(_("Number of Points:"))),	0, 1, 12, 13, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(spin_number_of_points,								1, 2, 12, 13, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+
+	options_table.attach(*manage(new Gtk::Label(_("Inner Tangent:"))),		0, 1, 13, 14, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(spin_inner_tangent,								1, 2, 13, 14, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+
+	options_table.attach(*manage(new Gtk::Label(_("Outer Tangent:"))),		0, 1, 14, 15, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(spin_outer_tangent,								1, 2, 14, 15, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+
+	options_table.attach(*manage(new Gtk::Label(_("Inner Width:"))),		0, 1, 15, 16, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(spin_inner_width,									1, 2, 15, 16, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+
+	options_table.attach(*manage(new Gtk::Label(_("Outer Width:"))),		0, 1, 16, 17, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(spin_outer_width,									1, 2, 16, 17, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+
+	options_table.attach(*manage(new Gtk::Label(_("Radius Ratio:"))),		0, 1, 17, 18, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(spin_radius_ratio,									1, 2, 17, 18, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+
+	options_table.attach(*manage(new Gtk::Label(_("Angle Offset:"))),		0, 1, 18, 19, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(spin_angle_offset,									1, 2, 18, 19, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 
 	options_table.show_all();
 
@@ -586,7 +606,19 @@ StateStar_Context::make_star(const Point& _p1, const Point& _p2)
 	Angle::deg offset(get_angle_offset());
 	bool regular(get_regular_polygon());
 	Angle::deg angle(360.0/points);
-	Real x(p1[0]), y(p1[1]);
+	Vector origin;
+	Real x, y;
+
+	if (get_layer_origins_at_center_flag())
+	{
+		x = y = 0;
+		origin = p1;
+	}
+	else
+	{
+		x = p1[0];
+		y = p1[1];
+	}
 
 	std::vector<BLinePoint> new_list;
 	int point(0);
@@ -595,7 +627,7 @@ StateStar_Context::make_star(const Point& _p1, const Point& _p2)
 		new_list.push_back(*(new BLinePoint));
 		new_list[point].set_width(outer_width);
 		new_list[point].set_vertex(Point(radius1*Angle::cos(angle*i + offset).get() + x,
-									 radius1*Angle::sin(angle*i + offset).get() + y));
+										 radius1*Angle::sin(angle*i + offset).get() + y));
 		new_list[point++].set_tangent(Point(-Angle::sin(angle*i + offset).get(),
 											 Angle::cos(angle*i + offset).get()) * outer_tangent);
 
@@ -613,7 +645,7 @@ StateStar_Context::make_star(const Point& _p1, const Point& _p2)
 	ValueNode_BLine::Handle value_node_bline(ValueNode_BLine::create(new_list));
 	assert(value_node_bline);
 
-	ValueNode_Const::Handle value_node_origin(ValueNode_Const::create(Vector()));
+	ValueNode_Const::Handle value_node_origin(ValueNode_Const::create(origin));
 	assert(value_node_origin);
 
 	// Set the looping flag
@@ -634,15 +666,18 @@ StateStar_Context::make_star(const Point& _p1, const Point& _p2)
 	if (get_layer_star_flag())
 	{
 		layer=get_canvas_interface()->add_layer_to("star",canvas,depth);
+		if (!layer)
+		{
+			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
+			group.cancel();
+			return;
+		}
 		layer_selection.push_back(layer);
 
-		layer->set_param("origin",p1);
-		get_canvas_interface()->signal_layer_param_changed()(layer,"origin");
-
-		layer->set_param("radius1",(p2-p1).mag());
+		layer->set_param("radius1",radius1);
 		get_canvas_interface()->signal_layer_param_changed()(layer,"radius1");
 
-		layer->set_param("radius2",(p2-p1).mag()/2);
+		layer->set_param("radius2",radius2);
 		get_canvas_interface()->signal_layer_param_changed()(layer,"radius2");
 
 		layer->set_param("angle",offset);
@@ -663,10 +698,33 @@ StateStar_Context::make_star(const Point& _p1, const Point& _p2)
 		layer->set_description(get_id());
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
 
-		if(get_layer_outline_flag())
+		// only link the star's origin parameter if the option is selected, we're putting bline
+		// origins at their centers, and we're creating more than one layer
+		if (get_layer_link_origins_flag() && get_layer_origins_at_center_flag() && layers_to_create > 1)
 		{
-			layer->set_param("color",synfigapp::Main::get_background_color());
-			get_canvas_interface()->signal_layer_param_changed()(layer,"color");
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
+			assert(action);
+
+			action->set_param("canvas",get_canvas());
+			action->set_param("canvas_interface",get_canvas_interface());
+			action->set_param("layer",layer);
+			if(!action->set_param("param",String("origin")))
+				synfig::error("LayerParamConnect didn't like \"param\"");
+			if(!action->set_param("value_node",ValueNode::Handle(value_node_origin)))
+				synfig::error("LayerParamConnect didn't like \"value_node\"");
+
+			if(!get_canvas_interface()->get_instance()->perform_action(action))
+			{
+				//get_canvas_view()->get_ui_interface()->error(_("Unable to create Star layer"));
+				group.cancel();
+				throw String(_("Unable to create Star layer"));
+				return;
+			}
+		}
+		else
+		{
+			layer->set_param("origin",p1);
+			get_canvas_interface()->signal_layer_param_changed()(layer,"origin");
 		}
 	}
 
@@ -679,13 +737,18 @@ StateStar_Context::make_star(const Point& _p1, const Point& _p2)
 		synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
 		Layer::Handle layer(get_canvas_interface()->add_layer_to("curve_gradient",canvas,depth));
-		assert(layer);
+		if (!layer)
+		{
+			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
+			group.cancel();
+			return;
+		}
 		layer_selection.push_back(layer);
 		layer->set_description(get_id()+_(" Gradient"));
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
 
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -708,7 +771,7 @@ StateStar_Context::make_star(const Point& _p1, const Point& _p2)
 		// only link the curve gradient's origin parameter if the option is selected and we're creating more than one layer
 		if (get_layer_link_origins_flag() && layers_to_create > 1)
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -727,6 +790,11 @@ StateStar_Context::make_star(const Point& _p1, const Point& _p2)
 				return;
 			}
 		}
+		else
+		{
+			layer->set_param("origin",origin);
+			get_canvas_interface()->signal_layer_param_changed()(layer,"origin");
+		}
 	}
 
 	///////////////////////////////////////////////////////////////////////////
@@ -738,13 +806,18 @@ StateStar_Context::make_star(const Point& _p1, const Point& _p2)
 		synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
 		Layer::Handle layer(get_canvas_interface()->add_layer_to("plant",canvas,depth));
-		assert(layer);
+		if (!layer)
+		{
+			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
+			group.cancel();
+			return;
+		}
 		layer_selection.push_back(layer);
 		layer->set_description(get_id()+_(" Plant"));
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
 
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -767,7 +840,7 @@ StateStar_Context::make_star(const Point& _p1, const Point& _p2)
 		// only link the plant's origin parameter if the option is selected and we're creating more than one layer
 		if (get_layer_link_origins_flag() && layers_to_create > 1)
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -786,6 +859,11 @@ StateStar_Context::make_star(const Point& _p1, const Point& _p2)
 				return;
 			}
 		}
+		else
+		{
+			layer->set_param("origin",origin);
+			get_canvas_interface()->signal_layer_param_changed()(layer,"origin");
+		}
 	}
 
 	///////////////////////////////////////////////////////////////////////////
@@ -797,7 +875,12 @@ StateStar_Context::make_star(const Point& _p1, const Point& _p2)
 		synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
 		Layer::Handle layer(get_canvas_interface()->add_layer_to("region",canvas,depth));
-		assert(layer);
+		if (!layer)
+		{
+			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
+			group.cancel();
+			return;
+		}
 		layer_selection.push_back(layer);
 		layer->set_description(get_id()+_(" Region"));
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
@@ -808,13 +891,10 @@ StateStar_Context::make_star(const Point& _p1, const Point& _p2)
 		layer->set_param("invert",get_invert());
 		get_canvas_interface()->signal_layer_param_changed()(layer,"invert");
 
-		if(get_layer_outline_flag())
-			layer->set_param("color",synfigapp::Main::get_background_color());
-
-		// I don't know if it's safe to reuse the same layer_param_connect action, so I'm
+		// I don't know if it's safe to reuse the same LayerParamConnect action, so I'm
 		// using 2 separate ones.
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -837,7 +917,7 @@ StateStar_Context::make_star(const Point& _p1, const Point& _p2)
 		// only link the region's origin parameter if the option is selected and we're creating more than one layer
 		if (get_layer_link_origins_flag() && layers_to_create > 1)
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -856,6 +936,11 @@ StateStar_Context::make_star(const Point& _p1, const Point& _p2)
 				return;
 			}
 		}
+		else
+		{
+			layer->set_param("origin",origin);
+			get_canvas_interface()->signal_layer_param_changed()(layer,"origin");
+		}
 	}
 
 	///////////////////////////////////////////////////////////////////////////
@@ -865,7 +950,12 @@ StateStar_Context::make_star(const Point& _p1, const Point& _p2)
 	if (get_layer_outline_flag())
 	{
 		Layer::Handle layer(get_canvas_interface()->add_layer_to("outline",canvas,depth));
-		assert(layer);
+		if (!layer)
+		{
+			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
+			group.cancel();
+			return;
+		}
 		layer_selection.push_back(layer);
 		layer->set_description(get_id()+_(" Outline"));
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
@@ -877,7 +967,7 @@ StateStar_Context::make_star(const Point& _p1, const Point& _p2)
 		get_canvas_interface()->signal_layer_param_changed()(layer,"invert");
 
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -900,7 +990,7 @@ StateStar_Context::make_star(const Point& _p1, const Point& _p2)
 		// only link the outline's origin parameter if the option is selected and we're creating more than one layer
 		if (get_layer_link_origins_flag() && layers_to_create > 1)
 		{
-			synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
+			synfigapp::Action::Handle action(synfigapp::Action::create("LayerParamConnect"));
 			assert(action);
 
 			action->set_param("canvas",get_canvas());
@@ -919,6 +1009,11 @@ StateStar_Context::make_star(const Point& _p1, const Point& _p2)
 				return;
 			}
 		}
+		else
+		{
+			layer->set_param("origin",origin);
+			get_canvas_interface()->signal_layer_param_changed()(layer,"origin");
+		}
 	}
 
 	egress_on_selection_change=false;
