@@ -2,7 +2,7 @@
 /*!	\file state_width.cpp
 **	\brief Template File
 **
-**	$Id: state_width.cpp 2098 2008-10-14 21:00:21Z genete $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -565,7 +565,7 @@ StateWidth_Context::event_mouse_handler(const Smach::event& x)
 
 			if(	desc.get_value_type() == ValueBase::TYPE_REAL )
 			{
-				Action::Handle action(Action::create("value_desc_set"));
+				Action::Handle action(Action::create("ValueDescSet"));
 				assert(action);
 
 				action->set_param("canvas",get_canvas());
