@@ -2,7 +2,7 @@
 /*!	\file widget_canvaschooser.cpp
 **	\brief Template File
 **
-**	$Id: widget_canvaschooser.cpp 1205 2007-12-17 09:43:41Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -146,16 +146,17 @@ Widget_CanvasChooser::chooser_menu()
 		set_value_(canvas);
 		return;
 	}
-		
+
 	Canvas::Handle new_canvas;
 	try
 	{
-		new_canvas=parent_canvas->find_canvas(canvas_name);
+		String warnings;
+		new_canvas=parent_canvas->find_canvas(canvas_name, warnings);
 		set_value_(new_canvas);
 	}
 	catch(std::runtime_error x)
 	{
-		App::dialog_error_blocking(_("Error:Exception Thrown"),x.what());
+		App::dialog_error_blocking(_("Error:Exception Thrown"),String(_("Error selecting canvas:\n\n")) + x.what());
 		set_value_(canvas);
 	}
 	catch(...)
