@@ -2,7 +2,7 @@
 /*!	\file widget_timeslider.cpp
 **	\brief Time Slider Widget Implementation File
 **
-**	$Id: widget_timeslider.cpp 2070 2008-09-24 13:51:53Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2004 Adrian Bentley
@@ -576,7 +576,17 @@ bool Widget_Timeslider::redraw(bool /*doublebuffer*/)
 
 			//gc->set_rgb_fg_color(Gdk::Color("#000000"));
 			layout->set_text(timecode);
-			window->draw_layout(gc,xpx+2,heightsmall,layout);
+			Pango::AttrList attr_list;
+			// Aproximately a font size of 8 pixels.
+			// Pango::SCALE = 1024
+			// create_attr_size waits a number in 1000th of pixels.
+			// Should be user customizable in the future. Now it is fixed to 10
+			Pango::AttrInt pango_size(Pango::Attribute::create_attr_size(Pango::SCALE*10));
+			pango_size.set_start_index(0);
+			pango_size.set_end_index(64);
+			attr_list.change(pango_size);
+			layout->set_attributes(attr_list);
+			window->draw_layout(gc,xpx+2,0,layout);
 		}else
 		{
 			window->draw_line(gc,xpx,0,xpx,heightsmall);
@@ -793,7 +803,7 @@ bool Widget_Timeslider::on_scroll_event(GdkEventScroll* event) //for zooming
 					else
 					{
 						adj_timescale->set_lower(start - (orig_t-t));
-						adj_timescale->set_upper(start - (orig_t-t) + (end-start)); 
+						adj_timescale->set_upper(start - (orig_t-t) + (end-start));
 					}
 				}
 			}
