@@ -2,7 +2,7 @@
 /*!	\file action.cpp
 **	\brief Template File
 **
-**	$Id: action.cpp 1923 2008-03-26 20:04:43Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -74,6 +74,8 @@
 #include "actions/waypointset.h"
 #include "actions/waypointsetsmart.h"
 #include "actions/waypointremove.h"
+#include "actions/waypointconnect.h"
+#include "actions/waypointdisconnect.h"
 // #include "actions/waypointsimpleadd.h"
 
 #include "actions/activepointadd.h"
@@ -192,6 +194,8 @@ Action::Main::Main()
 	ADD_ACTION(Action::WaypointSet);
 	ADD_ACTION(Action::WaypointSetSmart);
 	ADD_ACTION(Action::WaypointRemove);
+	ADD_ACTION(Action::WaypointConnect);
+	ADD_ACTION(Action::WaypointDisconnect);
 //	ADD_ACTION(Action::WaypointSimpleAdd);
 
 	ADD_ACTION(Action::ActivepointAdd);
@@ -222,7 +226,8 @@ Action::Main::Main()
 	ADD_ACTION(Action::BLinePointTangentSplit);
 
 	ADD_ACTION(Action::GradientSet);
-	ADD_ACTION(Action::ColorSet);
+	ADD_ACTION(Action::ColorSetFromOC);
+	ADD_ACTION(Action::ColorSetFromFC);
 
 	ADD_ACTION(Action::TimepointsMove);
 	ADD_ACTION(Action::TimepointsCopy);
@@ -267,12 +272,19 @@ Action::compile_candidate_list(const ParamList& param_list, Category category)
 		if((iter->second.category&category))
 		{
 			if(iter->second.is_candidate(param_list))
+			{
+				//synfig::info("Action \"%s\" is in",iter->second.name.c_str());
 				ret.push_back(iter->second);
+			}
 			else
 			{
 				//synfig::info("Action \"%s\" is not a candidate",iter->second.name.c_str());
 			}
 		}
+		else
+		{
+			//synfig::info("Action \"%s\" has unsuitable category",iter->second.name.c_str());
+		}
 	}
 
 	return ret;
@@ -373,6 +385,8 @@ Super::perform()
 	ActionList::const_iterator iter;
 	for(iter=action_list_.begin();iter!=action_list_.end();++iter)
 	{
+		//// debug actions
+		// synfig::info("%s:%d action: '%s'", __FILE__, __LINE__, (*iter)->get_name().c_str());
 		try
 		{
 			try
@@ -395,8 +409,10 @@ Super::perform()
 		}
 		catch(Error x)
 		{
-			throw Error(x.get_type(),((*iter)->get_name()+": "+x.get_desc()).c_str());
+			//synfig::info("%s:%d caught exception", __FILE__, __LINE__);
+			throw Error(x.get_type(),((*iter)->get_local_name()+": "+x.get_desc()).c_str());
 		}
+		//synfig::info("%s:%d finished action: '%s'", __FILE__, __LINE__, (*iter)->get_name().c_str());
 	}
 }
 
