@@ -2,7 +2,7 @@
 /*!	\file activepointadd.cpp
 **	\brief Template File
 **
-**	$Id: activepointadd.cpp 2098 2008-10-14 21:00:21Z genete $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -46,13 +46,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT(Action::ActivepointAdd);
-ACTION_SET_NAME(Action::ActivepointAdd,"activepoint_add");
+ACTION_SET_NAME(Action::ActivepointAdd,"ActivepointAdd");
 ACTION_SET_LOCAL_NAME(Action::ActivepointAdd,N_("Add Activepoint"));
 ACTION_SET_TASK(Action::ActivepointAdd,"add");
 ACTION_SET_CATEGORY(Action::ActivepointAdd,Action::CATEGORY_ACTIVEPOINT);
 ACTION_SET_PRIORITY(Action::ActivepointAdd,0);
 ACTION_SET_VERSION(Action::ActivepointAdd,"0.0");
-ACTION_SET_CVS_ID(Action::ActivepointAdd,"$Id: activepointadd.cpp 2098 2008-10-14 21:00:21Z genete $");
+ACTION_SET_CVS_ID(Action::ActivepointAdd,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
