@@ -2,7 +2,7 @@
 /*!	\file activepointset.cpp
 **	\brief Template File
 **
-**	$Id: activepointset.cpp 2098 2008-10-14 21:00:21Z genete $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -46,13 +46,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT(Action::ActivepointSet);
-ACTION_SET_NAME(Action::ActivepointSet,"activepoint_set");
+ACTION_SET_NAME(Action::ActivepointSet,"ActivepointSet");
 ACTION_SET_LOCAL_NAME(Action::ActivepointSet,N_("Set Activepoint"));
 ACTION_SET_TASK(Action::ActivepointSet,"set");
 ACTION_SET_CATEGORY(Action::ActivepointSet,Action::CATEGORY_ACTIVEPOINT);
 ACTION_SET_PRIORITY(Action::ActivepointSet,0);
 ACTION_SET_VERSION(Action::ActivepointSet,"0.0");
-ACTION_SET_CVS_ID(Action::ActivepointSet,"$Id: activepointset.cpp 2098 2008-10-14 21:00:21Z genete $");
+ACTION_SET_CVS_ID(Action::ActivepointSet,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
