@@ -2,7 +2,7 @@
 /*!	\file blinepointtangentmerge.cpp
 **	\brief Template File
 **
-**	$Id: blinepointtangentmerge.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -52,13 +52,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT_NO_GET_LOCAL_NAME(Action::BLinePointTangentMerge);
-ACTION_SET_NAME(Action::BLinePointTangentMerge,"bline_point_tangent_merge");
+ACTION_SET_NAME(Action::BLinePointTangentMerge,"BLinePointTangentMerge");
 ACTION_SET_LOCAL_NAME(Action::BLinePointTangentMerge,N_("Merge Tangents"));
 ACTION_SET_TASK(Action::BLinePointTangentMerge,"merge");
 ACTION_SET_CATEGORY(Action::BLinePointTangentMerge,Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::BLinePointTangentMerge,0);
 ACTION_SET_VERSION(Action::BLinePointTangentMerge,"0.0");
-ACTION_SET_CVS_ID(Action::BLinePointTangentMerge,"$Id: blinepointtangentmerge.cpp 1643 2008-02-09 19:12:18Z dooglus $");
+ACTION_SET_CVS_ID(Action::BLinePointTangentMerge,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
@@ -151,9 +151,9 @@ Action::BLinePointTangentMerge::prepare()
 
 	Action::Handle action;
 
-	action=Action::create("value_desc_set");
+	action=Action::create("ValueDescSet");
 	if(!action)
-		throw Error(_("Couldn't find action \"value_desc_set\""));
+		throw Error(_("Couldn't find action \"ValueDescSet\""));
 
 	action->set_param("canvas",get_canvas());
 	action->set_param("canvas_interface",get_canvas_interface());
