@@ -2,7 +2,7 @@
 /*!	\file groupremovelayers.cpp
 **	\brief Template File
 **
-**	$Id: groupremovelayers.cpp 1642 2008-02-09 18:25:35Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -46,13 +46,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT(Action::GroupRemoveLayers);
-ACTION_SET_NAME(Action::GroupRemoveLayers,"group_remove_layers");
+ACTION_SET_NAME(Action::GroupRemoveLayers,"GroupRemoveLayers");
 ACTION_SET_LOCAL_NAME(Action::GroupRemoveLayers,N_("Remove Layers from a Group"));
 ACTION_SET_TASK(Action::GroupRemoveLayers,"remove");
 ACTION_SET_CATEGORY(Action::GroupRemoveLayers,Action::CATEGORY_LAYER|Action::CATEGORY_GROUP);
 ACTION_SET_PRIORITY(Action::GroupRemoveLayers,0);
 ACTION_SET_VERSION(Action::GroupRemoveLayers,"0.0");
-ACTION_SET_CVS_ID(Action::GroupRemoveLayers,"$Id: groupremovelayers.cpp 1642 2008-02-09 18:25:35Z dooglus $");
+ACTION_SET_CVS_ID(Action::GroupRemoveLayers,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
