@@ -2,7 +2,7 @@
 /*!	\file keyframeadd.cpp
 **	\brief Template File
 **
-**	$Id: keyframeadd.cpp 1143 2007-11-13 09:13:07Z pabs $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -45,13 +45,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT(Action::KeyframeAdd);
-ACTION_SET_NAME(Action::KeyframeAdd,"keyframe_add");
+ACTION_SET_NAME(Action::KeyframeAdd,"KeyframeAdd");
 ACTION_SET_LOCAL_NAME(Action::KeyframeAdd,N_("Add Keyframe"));
 ACTION_SET_TASK(Action::KeyframeAdd,"add");
 ACTION_SET_CATEGORY(Action::KeyframeAdd,Action::CATEGORY_KEYFRAME);
 ACTION_SET_PRIORITY(Action::KeyframeAdd,0);
 ACTION_SET_VERSION(Action::KeyframeAdd,"0.0");
-ACTION_SET_CVS_ID(Action::KeyframeAdd,"$Id: keyframeadd.cpp 1143 2007-11-13 09:13:07Z pabs $");
+ACTION_SET_CVS_ID(Action::KeyframeAdd,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
