@@ -2,7 +2,7 @@
 /*!	\file keyframeduplicate.cpp
 **	\brief Template File
 **
-**	$Id: keyframeduplicate.cpp 1143 2007-11-13 09:13:07Z pabs $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -49,13 +49,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT(Action::KeyframeDuplicate);
-ACTION_SET_NAME(Action::KeyframeDuplicate,"keyframe_duplicate");
+ACTION_SET_NAME(Action::KeyframeDuplicate,"KeyframeDuplicate");
 ACTION_SET_LOCAL_NAME(Action::KeyframeDuplicate,N_("Duplicate Keyframe"));
 ACTION_SET_TASK(Action::KeyframeDuplicate,"duplicate");
 ACTION_SET_CATEGORY(Action::KeyframeDuplicate,Action::CATEGORY_KEYFRAME);
 ACTION_SET_PRIORITY(Action::KeyframeDuplicate,0);
 ACTION_SET_VERSION(Action::KeyframeDuplicate,"0.0");
-ACTION_SET_CVS_ID(Action::KeyframeDuplicate,"$Id: keyframeduplicate.cpp 1143 2007-11-13 09:13:07Z pabs $");
+ACTION_SET_CVS_ID(Action::KeyframeDuplicate,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
