@@ -2,7 +2,7 @@
 /*!	\file layerencapsulate.cpp
 **	\brief Template File
 **
-**	$Id: layerencapsulate.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -48,13 +48,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT_NO_GET_LOCAL_NAME(Action::LayerEncapsulate);
-ACTION_SET_NAME(Action::LayerEncapsulate,"layer_encapsulate");
+ACTION_SET_NAME(Action::LayerEncapsulate,"LayerEncapsulate");
 ACTION_SET_LOCAL_NAME(Action::LayerEncapsulate,N_("Encapsulate"));
 ACTION_SET_TASK(Action::LayerEncapsulate,"encapsulate");
 ACTION_SET_CATEGORY(Action::LayerEncapsulate,Action::CATEGORY_LAYER);
 ACTION_SET_PRIORITY(Action::LayerEncapsulate,0);
 ACTION_SET_VERSION(Action::LayerEncapsulate,"0.0");
-ACTION_SET_CVS_ID(Action::LayerEncapsulate,"$Id: layerencapsulate.cpp 1643 2008-02-09 19:12:18Z dooglus $");
+ACTION_SET_CVS_ID(Action::LayerEncapsulate,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
@@ -163,7 +163,7 @@ Action::LayerEncapsulate::prepare()
 
 	// Move the layer
 	{
-		Action::Handle action(Action::create("layer_move"));
+		Action::Handle action(Action::create("LayerMove"));
 
 		assert(action);
 
