@@ -2,7 +2,7 @@
 /*!	\file valuedescconvert.cpp
 **	\brief Template File
 **
-**	$Id: valuedescconvert.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -56,13 +56,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT_NO_GET_LOCAL_NAME(Action::ValueDescConvert);
-ACTION_SET_NAME(Action::ValueDescConvert,"value_desc_convert");
+ACTION_SET_NAME(Action::ValueDescConvert,"ValueDescConvert");
 ACTION_SET_LOCAL_NAME(Action::ValueDescConvert,N_("Convert"));
 ACTION_SET_TASK(Action::ValueDescConvert,"convert");
 ACTION_SET_CATEGORY(Action::ValueDescConvert,Action::CATEGORY_VALUEDESC);
 ACTION_SET_PRIORITY(Action::ValueDescConvert,0);
 ACTION_SET_VERSION(Action::ValueDescConvert,"0.0");
-ACTION_SET_CVS_ID(Action::ValueDescConvert,"$Id: valuedescconvert.cpp 1643 2008-02-09 19:12:18Z dooglus $");
+ACTION_SET_CVS_ID(Action::ValueDescConvert,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
