@@ -2,7 +2,7 @@
 /*!	\file valuedescdisconnect.cpp
 **	\brief Template File
 **
-**	$Id: valuedescdisconnect.cpp 1864 2008-03-06 20:37:48Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -31,6 +31,7 @@
 #endif
 
 #include "layerparamdisconnect.h"
+#include "waypointdisconnect.h"
 #include "valuenodelinkdisconnect.h"
 #include "valuenodereplace.h"
 
@@ -52,13 +53,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT_NO_GET_LOCAL_NAME(Action::ValueDescDisconnect);
-ACTION_SET_NAME(Action::ValueDescDisconnect,"value_desc_disconnect");
+ACTION_SET_NAME(Action::ValueDescDisconnect,"ValueDescDisconnect");
 ACTION_SET_LOCAL_NAME(Action::ValueDescDisconnect,N_("Disconnect"));
 ACTION_SET_TASK(Action::ValueDescDisconnect,"disconnect");
 ACTION_SET_CATEGORY(Action::ValueDescDisconnect,Action::CATEGORY_VALUEDESC);
 ACTION_SET_PRIORITY(Action::ValueDescDisconnect,-100);
 ACTION_SET_VERSION(Action::ValueDescDisconnect,"0.0");
-ACTION_SET_CVS_ID(Action::ValueDescDisconnect,"$Id: valuedescdisconnect.cpp 1864 2008-03-06 20:37:48Z dooglus $");
+ACTION_SET_CVS_ID(Action::ValueDescDisconnect,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
@@ -177,6 +178,24 @@ Action::ValueDescDisconnect::prepare()
 		return;
 	}
 	else
+	if(value_desc.parent_is_waypoint())
+	{
+		Action::Handle action(WaypointDisconnect::create());
+
+		action->set_param("canvas",get_canvas());
+		action->set_param("canvas_interface",get_canvas_interface());
+		action->set_param("parent_value_node",value_desc.get_parent_value_node());
+		action->set_param("waypoint_time",value_desc.get_waypoint_time());
+		action->set_param("time",time);
+
+		assert(action->is_ready());
+		if(!action->is_ready())
+			throw Error(Error::TYPE_NOTREADY);
+
+		add_action_front(action);
+		return;
+	}
+	else
 	if(value_desc.parent_is_linkable_value_node())
 	{
 		Action::Handle action(ValueNodeLinkDisconnect::create());
