@@ -2,7 +2,7 @@
 /*!	\file valuedescset.cpp
 **	\brief Template File
 **
-**	$Id: valuedescset.cpp 1760 2008-02-19 15:34:43Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -55,13 +55,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT_NO_GET_LOCAL_NAME(Action::ValueDescSet);
-ACTION_SET_NAME(Action::ValueDescSet,"value_desc_set");
+ACTION_SET_NAME(Action::ValueDescSet,"ValueDescSet");
 ACTION_SET_LOCAL_NAME(Action::ValueDescSet,N_("Set ValueDesc"));
 ACTION_SET_TASK(Action::ValueDescSet,"set");
 ACTION_SET_CATEGORY(Action::ValueDescSet,Action::CATEGORY_VALUEDESC);
 ACTION_SET_PRIORITY(Action::ValueDescSet,0);
 ACTION_SET_VERSION(Action::ValueDescSet,"0.0");
-ACTION_SET_CVS_ID(Action::ValueDescSet,"$Id: valuedescset.cpp 1760 2008-02-19 15:34:43Z dooglus $");
+ACTION_SET_CVS_ID(Action::ValueDescSet,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
@@ -174,10 +174,10 @@ Action::ValueDescSet::prepare()
 
 			assert(parent_value_node);
 
-			Action::Handle action(Action::create("value_desc_set"));
+			Action::Handle action(Action::create("ValueDescSet"));
 
 			if(!action)
-				throw Error(_("Unable to find action value_desc_set (bug)"));
+				throw Error(_("Unable to find action ValueDescSet (bug)"));
 
 			action->set_param("canvas",get_canvas());
 			action->set_param("canvas_interface",get_canvas_interface());
@@ -199,10 +199,10 @@ Action::ValueDescSet::prepare()
 	{
 		ValueDesc reference_value_desc(ValueNode_Reference::Handle::cast_dynamic(value_desc.get_value_node()),0);
 
-		Action::Handle action(Action::create("value_desc_set"));
+		Action::Handle action(Action::create("ValueDescSet"));
 
 		if(!action)
-			throw Error(_("Unable to find action value_desc_set (bug)"));
+			throw Error(_("Unable to find action ValueDescSet (bug)"));
 
 		action->set_param("canvas",get_canvas());
 		action->set_param("canvas_interface",get_canvas_interface());
@@ -267,10 +267,10 @@ Action::ValueDescSet::prepare()
 		{
 			ValueDesc component_value_desc(ValueNode_Composite::Handle::cast_dynamic(value_desc.get_value_node()),i);
 
-			Action::Handle action(Action::create("value_desc_set"));
+			Action::Handle action(Action::create("ValueDescSet"));
 
 			if(!action)
-				throw Error(_("Unable to find action value_desc_set (bug)"));
+				throw Error(_("Unable to find action ValueDescSet (bug)"));
 
 			action->set_param("canvas",get_canvas());
 			action->set_param("canvas_interface",get_canvas_interface());
@@ -325,10 +325,10 @@ Action::ValueDescSet::prepare()
 		{
 			ValueDesc component_value_desc(ValueNode_RadialComposite::Handle::cast_dynamic(value_desc.get_value_node()),i);
 
-			Action::Handle action(Action::create("value_desc_set"));
+			Action::Handle action(Action::create("ValueDescSet"));
 
 			if(!action)
-				throw Error(_("Unable to find action value_desc_set (bug)"));
+				throw Error(_("Unable to find action ValueDescSet (bug)"));
 
 			action->set_param("canvas",get_canvas());
 			action->set_param("canvas_interface",get_canvas_interface());
@@ -362,10 +362,10 @@ Action::ValueDescSet::prepare()
 	    {
 			// we are splitting tangents
 
-			Action::Handle action(Action::create("value_desc_set"));
+			Action::Handle action(Action::create("ValueDescSet"));
 
 			if(!action)
-				throw Error(_("Unable to find action value_desc_set (bug)"));
+				throw Error(_("Unable to find action ValueDescSet (bug)"));
 
 			action->set_param("canvas",get_canvas());
 			action->set_param("canvas_interface",get_canvas_interface());
@@ -387,10 +387,10 @@ Action::ValueDescSet::prepare()
 							   (Vector)((*parent_value_node->get_link("t2"))(time))) / 2);
 
 			{
-				Action::Handle action(Action::create("value_desc_set"));
+				Action::Handle action(Action::create("ValueDescSet"));
 
 				if(!action)
-					throw Error(_("Unable to find action value_desc_set (bug)"));
+					throw Error(_("Unable to find action ValueDescSet (bug)"));
 
 				action->set_param("canvas",get_canvas());
 				action->set_param("canvas_interface",get_canvas_interface());
@@ -405,10 +405,10 @@ Action::ValueDescSet::prepare()
 			}
 
 			{
-				Action::Handle action(Action::create("value_desc_set"));
+				Action::Handle action(Action::create("ValueDescSet"));
 
 				if(!action)
-					throw Error(_("Unable to find action value_desc_set (bug)"));
+					throw Error(_("Unable to find action ValueDescSet (bug)"));
 
 				action->set_param("canvas",get_canvas());
 				action->set_param("canvas_interface",get_canvas_interface());
@@ -475,7 +475,7 @@ Action::ValueDescSet::prepare()
 			}
 			else
 			{
-				action=Action::create("value_node_replace");
+				action=Action::create("ValueNodeReplace");
 				action->set_param("dest",value_desc.get_value_node());
 				action->set_param("src",ValueNode::Handle(value_node));
 			}
