@@ -2,7 +2,7 @@
 /*!	\file valuenodedynamiclistinsert.cpp
 **	\brief Template File
 **
-**	$Id: valuenodedynamiclistinsert.cpp 2098 2008-10-14 21:00:21Z genete $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -46,13 +46,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT(Action::ValueNodeDynamicListInsert);
-ACTION_SET_NAME(Action::ValueNodeDynamicListInsert,"value_node_dynamic_list_insert");
+ACTION_SET_NAME(Action::ValueNodeDynamicListInsert,"ValueNodeDynamicListInsert");
 ACTION_SET_LOCAL_NAME(Action::ValueNodeDynamicListInsert,N_("Insert Item"));
 ACTION_SET_TASK(Action::ValueNodeDynamicListInsert,"insert");
 ACTION_SET_CATEGORY(Action::ValueNodeDynamicListInsert,Action::CATEGORY_VALUEDESC|Action::CATEGORY_VALUENODE|Action::CATEGORY_HIDDEN);
 ACTION_SET_PRIORITY(Action::ValueNodeDynamicListInsert,-20);
 ACTION_SET_VERSION(Action::ValueNodeDynamicListInsert,"0.0");
-ACTION_SET_CVS_ID(Action::ValueNodeDynamicListInsert,"$Id: valuenodedynamiclistinsert.cpp 2098 2008-10-14 21:00:21Z genete $");
+ACTION_SET_CVS_ID(Action::ValueNodeDynamicListInsert,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
