@@ -2,7 +2,7 @@
 /*!	\file valuenodedynamiclistloop.cpp
 **	\brief Template File
 **
-**	$Id: valuenodedynamiclistloop.cpp 2098 2008-10-14 21:00:21Z genete $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -46,13 +46,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT(Action::ValueNodeDynamicListLoop);
-ACTION_SET_NAME(Action::ValueNodeDynamicListLoop,"value_node_dynamic_list_loop");
+ACTION_SET_NAME(Action::ValueNodeDynamicListLoop,"ValueNodeDynamicListLoop");
 ACTION_SET_LOCAL_NAME(Action::ValueNodeDynamicListLoop,N_("Loop"));
 ACTION_SET_TASK(Action::ValueNodeDynamicListLoop,"loop");
 ACTION_SET_CATEGORY(Action::ValueNodeDynamicListLoop,Action::CATEGORY_VALUEDESC|Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::ValueNodeDynamicListLoop,0);
 ACTION_SET_VERSION(Action::ValueNodeDynamicListLoop,"0.0");
-ACTION_SET_CVS_ID(Action::ValueNodeDynamicListLoop,"$Id: valuenodedynamiclistloop.cpp 2098 2008-10-14 21:00:21Z genete $");
+ACTION_SET_CVS_ID(Action::ValueNodeDynamicListLoop,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
