@@ -2,7 +2,7 @@
 /*!	\file valuenodedynamiclistremovesmart.cpp
 **	\brief Template File
 **
-**	$Id: valuenodedynamiclistremovesmart.cpp 2098 2008-10-14 21:00:21Z genete $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -47,13 +47,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT(Action::ValueNodeDynamicListRemoveSmart);
-ACTION_SET_NAME(Action::ValueNodeDynamicListRemoveSmart,"value_node_dynamic_list_remove_smart");
+ACTION_SET_NAME(Action::ValueNodeDynamicListRemoveSmart,"ValueNodeDynamicListRemoveSmart");
 ACTION_SET_LOCAL_NAME(Action::ValueNodeDynamicListRemoveSmart,N_("Remove Item (Smart)"));
 ACTION_SET_TASK(Action::ValueNodeDynamicListRemoveSmart,"remove");
 ACTION_SET_CATEGORY(Action::ValueNodeDynamicListRemoveSmart,Action::CATEGORY_VALUEDESC|Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::ValueNodeDynamicListRemoveSmart,-19);
 ACTION_SET_VERSION(Action::ValueNodeDynamicListRemoveSmart,"0.0");
-ACTION_SET_CVS_ID(Action::ValueNodeDynamicListRemoveSmart,"$Id: valuenodedynamiclistremovesmart.cpp 2098 2008-10-14 21:00:21Z genete $");
+ACTION_SET_CVS_ID(Action::ValueNodeDynamicListRemoveSmart,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
@@ -153,7 +153,7 @@ Action::ValueNodeDynamicListRemoveSmart::prepare()
 	// If we are in animate editing mode
 	if(get_edit_mode()&MODE_ANIMATE)
 	{
-		Action::Handle action(Action::create("activepoint_set_off"));
+		Action::Handle action(Action::create("ActivepointSetOff"));
 
 		if(!action)
 			throw Error(_("Unable to find action (bug)"));
@@ -171,7 +171,7 @@ Action::ValueNodeDynamicListRemoveSmart::prepare()
 	}
 	else
 	{
-		Action::Handle action(Action::create("value_node_dynamic_list_remove"));
+		Action::Handle action(Action::create("ValueNodeDynamicListRemove"));
 
 		if(!action)
 			throw Error(_("Unable to find action (bug)"));
