@@ -2,11 +2,12 @@
 /*!	\file canvasinterface.cpp
 **	\brief Template File
 **
-**	$Id: canvasinterface.cpp 1923 2008-03-26 20:04:43Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
+**	Copyright (c) 2009 Carlos A. Sosa Navarro
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -52,6 +53,7 @@
 #include "instance.h"
 
 #include "actions/layeradd.h"
+#include "actions/layerremove.h"
 #include "actions/valuedescconvert.h"
 #include "actions/valuenodeadd.h"
 #include "actions/editmodeset.h"
@@ -214,10 +216,12 @@ CanvasInterface::add_layer_to(synfig::String name, synfig::Canvas::Handle canvas
 	layer->set_canvas(canvas);
 
 	// Apply some defaults
-	if(layer->set_param("fg",synfigapp::Main::get_foreground_color()))
-		layer->set_param("bg",synfigapp::Main::get_background_color());
+	if(layer->set_param("fg",synfigapp::Main::get_outline_color()))
+		layer->set_param("bg",synfigapp::Main::get_fill_color());
+	else if (name == "outline")
+		layer->set_param("color",synfigapp::Main::get_outline_color());
 	else
-		layer->set_param("color",synfigapp::Main::get_foreground_color());
+		layer->set_param("color",synfigapp::Main::get_fill_color());
 
 	layer->set_param("width",synfigapp::Main::get_bline_width().units(get_canvas()->rend_desc()));
 	layer->set_param("gradient",synfigapp::Main::get_gradient());
@@ -300,7 +304,7 @@ CanvasInterface::add_layer_to(synfig::String name, synfig::Canvas::Handle canvas
 	// Action to move the layer (if necessary)
 	if(depth>0)
 	{
-		Action::Handle 	action(Action::create("layer_move"));
+		Action::Handle 	action(Action::create("LayerMove"));
 
 		assert(action);
 		if(!action)
@@ -463,7 +467,7 @@ CanvasInterface::generate_param_list(const std::list<synfigapp::ValueDesc> &valu
 void
 CanvasInterface::set_rend_desc(const synfig::RendDesc &rend_desc)
 {
-	Action::Handle 	action(Action::create("canvas_rend_desc_set"));
+	Action::Handle 	action(Action::create("CanvasRendDescSet"));
 
 	assert(action);
 	if(!action)
@@ -480,7 +484,7 @@ CanvasInterface::set_rend_desc(const synfig::RendDesc &rend_desc)
 void
 CanvasInterface::set_name(const synfig::String &x)
 {
-	Action::Handle 	action(Action::create("canvas_name_set"));
+	Action::Handle 	action(Action::create("CanvasNameSet"));
 
 	assert(action);
 	if(!action)
@@ -499,7 +503,7 @@ CanvasInterface::set_name(const synfig::String &x)
 void
 CanvasInterface::set_description(const synfig::String &x)
 {
-	Action::Handle 	action(Action::create("canvas_description_set"));
+	Action::Handle 	action(Action::create("CanvasDescriptionSet"));
 
 	assert(action);
 	if(!action)
@@ -516,7 +520,7 @@ CanvasInterface::set_description(const synfig::String &x)
 void
 CanvasInterface::set_id(const synfig::String &x)
 {
-	Action::Handle 	action(Action::create("canvas_id_set"));
+	Action::Handle 	action(Action::create("CanvasIdSet"));
 
 	assert(action);
 	if(!action)
@@ -560,7 +564,7 @@ CanvasInterface::jump_to_prev_keyframe()
 }
 
 bool
-CanvasInterface::import(const synfig::String &filename, bool /*copy*/)
+CanvasInterface::import(const synfig::String &filename, synfig::String &errors, synfig::String &warnings, bool resize_image)
 {
 	Action::PassiveGrouper group(get_instance().get(),_("Import Image"));
 
@@ -576,19 +580,46 @@ CanvasInterface::import(const synfig::String &filename, bool /*copy*/)
 	if (ext.size()) ext = ext.substr(1); // skip initial '.'
 	std::transform(ext.begin(),ext.end(),ext.begin(),&::tolower);
 
+	if(ext=="svg"){//I don't like it, but worse is nothing
+		Layer::Handle _new_layer(add_layer_to("PasteCanvas",get_canvas()));
+		Layer::Handle _aux_layer(add_layer_to("svg_layer",get_canvas()));
+		if(_aux_layer){
+			_aux_layer->set_param("filename",ValueBase(filename));
+			_new_layer->set_param("canvas",ValueBase(_aux_layer->get_param("canvas")));
+			//remove aux layer
+			Action::Handle 	action(Action::LayerRemove::create());
+			assert(action);
+			if(!action)
+				return 0;
+			action->set_param("canvas",get_canvas());
+			action->set_param("canvas_interface",etl::loose_handle<CanvasInterface>(this));
+			action->set_param("layer",_aux_layer);
+			if(!action->is_ready()){
+				get_ui_interface()->error(_("Action Not Ready"));
+				return 0;
+			}
+			if(!get_instance()->perform_action(action)){
+				get_ui_interface()->error(_("Action Failed."));
+				return 0;
+			}
+		}
+		signal_layer_new_description()(_new_layer,filename);
+		return true;
+	}
+
 	// If this is a SIF file, then we need to do things slightly differently
 	if(ext=="sif" || ext=="sifz")try
 	{
-
-		Canvas::Handle outside_canvas(synfig::open_canvas(filename));
+		Canvas::Handle outside_canvas(synfig::open_canvas(filename, errors, warnings));
 		if(!outside_canvas)
-			throw String(_("Unable to open this composition"));
+			throw String(_("Unable to open this composition")) + ":\n\n" + errors;
 
 		Layer::Handle layer(add_layer_to("PasteCanvas",get_canvas()));
 		if(!layer)
 			throw String(_("Unable to create \"Paste Canvas\" layer"));
 		if(!layer->set_param("canvas",ValueBase(outside_canvas)))
 			throw int();
+		get_canvas()->register_external_canvas(filename, outside_canvas);
 
 		//layer->set_description(basename(filename));
 		signal_layer_new_description()(layer,filename);
@@ -596,7 +627,7 @@ CanvasInterface::import(const synfig::String &filename, bool /*copy*/)
 	}
 	catch(String x)
 	{
-		get_ui_interface()->error(x+" -- "+filename);
+		get_ui_interface()->error(filename + ": " + x);
 		return false;
 	}
 	catch(...)
@@ -623,22 +654,34 @@ CanvasInterface::import(const synfig::String &filename, bool /*copy*/)
 		h=layer->get_param("_height").get(int());
 		if(w&&h)
 		{
-			Vector size=ValueBase(get_canvas()->rend_desc().get_br()-get_canvas()->rend_desc().get_tl());
-			Vector x;
-			if(size[0]<size[1])
+			Vector x, size=ValueBase(get_canvas()->rend_desc().get_br()-get_canvas()->rend_desc().get_tl());
+
+			// vector from top left of canvas to bottom right
+			if (resize_image)
 			{
-				x[0]=size[0];
-				x[1]=size[0]/w*h;
-				if((size[0]<0) ^ (size[1]<0))
-					x[1]=-x[1];
+				if(abs(size[0])<abs(size[1]))	// if canvas is tall and thin
+				{
+					x[0]=size[0];	// use full width
+					x[1]=size[0]/w*h; // and scale for height
+					if((size[0]<0) ^ (size[1]<0))
+						x[1]=-x[1];
+				}
+				else				// else canvas is short and fat (or maybe square)
+				{
+					x[1]=size[1];	// use full height
+					x[0]=size[1]/h*w; // and scale for width
+					if((size[0]<0) ^ (size[1]<0))
+						x[0]=-x[0];
+				}
 			}
 			else
 			{
-				x[1]=size[1];
-				x[0]=size[1]/h*w;
-				if((size[0]<0) ^ (size[1]<0))
-					x[0]=-x[0];
+				x[0] = w/60.0;
+				x[1] = h/60.0;
+				if((size[0]<0)) x[0]=-x[0];
+				if((size[1]<0)) x[1]=-x[1];
 			}
+
 			if(!layer->set_param("tl",ValueBase(-x/2)))
 				throw int();
 			if(!layer->set_param("br",ValueBase(x/2)))
@@ -676,7 +719,7 @@ CanvasInterface::waypoint_duplicate(synfigapp::ValueDesc value_desc,synfig::Wayp
 void
 CanvasInterface::waypoint_duplicate(ValueNode::Handle value_node,synfig::Waypoint waypoint)
 {
-	Action::Handle 	action(Action::create("waypoint_set_smart"));
+	Action::Handle 	action(Action::create("WaypointSetSmart"));
 
 	assert(action);
 	if(!action)
@@ -705,7 +748,7 @@ CanvasInterface::waypoint_remove(synfigapp::ValueDesc value_desc,synfig::Waypoin
 void
 CanvasInterface::waypoint_remove(ValueNode::Handle value_node,synfig::Waypoint waypoint)
 {
-	Action::Handle 	action(Action::create("waypoint_remove"));
+	Action::Handle 	action(Action::create("WaypointRemove"));
 
 	assert(action);
 	if(!action)
@@ -729,7 +772,7 @@ CanvasInterface::auto_export(synfig::ValueNode::Handle /*value_node*/)
 	if(value_node->is_exported())
 		return;
 
-	Action::Handle 	action(Action::create("value_node_add"));
+	Action::Handle 	action(Action::create("ValueNodeAdd"));
 
 	assert(action);
 	if(!action)
@@ -756,7 +799,7 @@ CanvasInterface::auto_export(const ValueDesc& /*value_desc*/)
 	if(value_desc.is_exported())
 		return;
 
-	Action::Handle 	action(Action::create("value_desc_export"));
+	Action::Handle 	action(Action::create("ValueDescExport"));
 
 	assert(action);
 	if(!action)
@@ -803,7 +846,7 @@ CanvasInterface::change_value(synfigapp::ValueDesc value_desc,synfig::ValueBase
 	{ synfig::warning("Can't get canvas from value desc...?"); }
 #endif
 
-	synfigapp::Action::Handle action(synfigapp::Action::create("value_desc_set"));
+	synfigapp::Action::Handle action(synfigapp::Action::create("ValueDescSet"));
 	if(!action)
 	{
 		return false;
