@@ -2,7 +2,7 @@
 /*!	\file canvasinterface.h
 **	\brief Template Header
 **
-**	$Id: canvasinterface.h 1923 2008-03-26 20:04:43Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -256,7 +256,7 @@ public:
 	Mode get_mode()const;
 
 	//! Creates a new layer, of type \c id at the top of the layer stack
-	synfig::Layer::Handle add_layer(synfig::String id) { return add_layer_to(id,get_canvas()); }
+	// synfig::Layer::Handle add_layer(synfig::String id) { return add_layer_to(id,get_canvas()); }
 
 	synfig::Layer::Handle add_layer_to(synfig::String id,synfig::Canvas::Handle canvas, int depth=0);
 
@@ -271,7 +271,7 @@ public:
 
 	void set_rend_desc(const synfig::RendDesc &rend_desc);
 
-	bool import(const synfig::String &filename, bool copy=false);
+	bool import(const synfig::String &filename, synfig::String &errors, synfig::String &warnings, bool resize_image=false);
 
 
 	void waypoint_duplicate(synfigapp::ValueDesc value_desc,synfig::Waypoint waypoint);
